# -*- coding: utf-8 -*-

from ..utils import *


class bloco_c(TrackedAttributesClass):
    """
    BLOCO C: DOCUMENTOS FISCAIS I - MERCADORIAS (ICMS/IPI)
    """

    class registro_C001(TrackedAttributesClass):
        """
        REGISTRO C001: ABERTURA DO BLOCO C
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C001, self).__init__()
            self.REG = 'C001'         #Texto fixo contendo
            self.nivel_h = 1          #nível
            self.pai = '0000'
            self.ocorrencia = '1'     #ocorrência por arquivo
            self.IND_MOV = '0'         #Indicador de movimento:0- Bloco com dados informados;1- Bloco sem dados informados.
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'IND_MOV': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
            }
            self.fieldnames = ('REG', 'IND_MOV')
            self.formato = self.get_formato()

    class registro_C010(TrackedAttributesClass):
        """
        REGISTRO C010: IDENTIFICAÇÃO DO ESTABELECIMENTO
        Este registro tem o objetivo de identificar o estabelecimento da pessoa jurídica a que se referem as operações e
        documentos fiscais informados neste bloco. Só devem ser escriturados no Registro C010 os estabelecimentos que
        efetivamente tenham realizado aquisição, venda ou devolução de mercadorias, bens e produtos, mediante emissão de
        documento fiscal definido pela legislação do ICMS e do IPI, que devam ser escrituradas no Bloco C.
        O estabelecimento que não realizou operações passíveis de registro nesse bloco, no período da escrituração, não deve ser
        identificado no Registro C010.
        Para cada estabelecimento cadastrado em “C010”, deve ser informado nos registros de nível inferior (Registros Filho) as
        operações próprias de prestação ou de contratação de serviços, mediante emissão de documento fiscal, no mercado
        interno ou externo.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C010, self).__init__()
            self.REG = 'C010'         #Texto fixo contendo
            self.nivel_h = 2          #nível
            self.pai = 'C001'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.CNPJ = ''
            self.IND_ESCRI = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'CNPJ': {'tipo': 'N', 'tamanho': 14, 'fixa_tamanho': True},
                'IND_ESCRI': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
            }
            self.fieldnames = ('REG', 'CNPJ', 'IND_ESCRI')
            self.formato = self.get_formato()

    class registro_C100(TrackedAttributesClass):
        """
        REGISTRO C100: DOCUMENTO - NOTA FISCAL (CÓDIGO 01), NOTA FISCAL AVULSA
        (CÓDIGO 1B), NOTA FISCAL DE PRODUTOR (CÓDIGO 04) e NF-e (CÓDIGO 55)
        Registro com estrutura, campos e conteúdo definidos e constantes no Leiaute da Escrituração Fiscal Digital – EFD (ICMS
        e IPI), instituído pelo Ato COTEPE/ICMS no 9, de 12 de abril de 2008, disponível no portal de serviços (SPED) da
        página da Secretaria da Receita Federal do Brasil na Internet, no endereço <www.receita.fazenda.gov.br/sped>.
        Este registro deve ser gerado para cada documento fiscal código 01, 1B, 04 e 55, registrando a entrada ou saída de
        produtos ou outras situações que envolvam a emissão dos documentos fiscais mencionados, representativos de receitas
        auferidas, tributadas ou não pelo PIS/Pasep ou pela Cofins, bem como de operações de aquisições e/ou devoluções com
        direito a crédito da não cumulatividade.

        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C100, self).__init__()
            self.REG = 'C100'         #Texto fixo contendo
            self.nivel_h = 3          #nível
            self.pai = 'C001'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.IND_OPER = ''        #Indicador do tipo de operação:   0- Entrada;   1- Saída
            self.IND_EMIT = ''        #Indicador do emitente do documento fiscal: 0- Emissão própria; 1- Terceiros
            self.COD_PART = ''        #Código do participante (campo 02 do Registro  0150):  - do emitente do documento ou do remetente das ercadorias, no caso de entradas; - do adquirente, no caso de saídas
            self.COD_MOD = ''         #Código do modelo do documento fiscal, conforme a Tabela 4.1.1
            self.COD_SIT = ''         #Código da situação do documento fiscal,  conforme a Tabela 4.1.2
            self.SER = ''             #Série do documento fiscal
            self.NUM_DOC = ''         #Número do documento fiscal
            self.CHV_NFE = ''         #Chave da Nota Fiscal Eletrônica
            self.DT_DOC = ''          #Data da emissão do documento fiscal
            self.DT_E_S = ''          #Data da entrada ou da saída
            self.VL_DOC = ''          #Valor total do documento fiscal
            self.IND_PGTO = ''        #Indicador do tipo de pagamento:  0- À vista;   1- A prazo;  9- Sem pagamento.
            self.VL_DESC = ''         #Valor total do desconto
            self.VL_ABAT_NT = ''      #Abatimento não tributado e não comercial Ex.desconto ICMS nas remessas para ZFM.
            self.VL_MERC = ''         #Valor total das mercadorias e serviços
            self.IND_FRT = ''         #Indicador do tipo do frete:  0- Por conta do emitente; 1- Por conta do destinatário/remetente;  2- Por conta de terceiros;  9- Sem cobrança de frete.
            self.VL_FRT = ''          #Valor do frete indicado no documento fiscal
            self.VL_SEG = ''          #Valor do seguro indicado no documento fiscal
            self.VL_OUT_DA = ''       #Valor de outras despesas acessórias
            self.VL_BC_ICMS = ''      #Valor da base de cálculo do ICMS
            self.VL_ICMS = ''         #Valor do ICMS
            self.VL_BC_ICMS_ST = ''   #Valor da base de cálculo do ICMS substituição tributária
            self.VL_ICMS_ST = ''      #Valor do ICMS retido por substituição tributária
            self.VL_IPI = ''          #Valor total do IPI
            self.VL_PIS = ''          #Valor total do PIS
            self.VL_COFINS = ''       #Valor total da COFINS
            self.VL_PIS_ST = ''       #Valor total do PIS retido por substituição tributária
            self.VL_COFINS_ST = ''    #Valor total da COFINS retido por substituição tributária
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'IND_OPER': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
                'IND_EMIT': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
                'COD_PART': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'COD_MOD': {'tipo': 'C', 'tamanho': 2, 'fixa_tamanho': True},
                'COD_SIT': {'tipo': 'N', 'tamanho': 2, 'fixa_tamanho': True},
                'SER': {'tipo': 'C', 'tamanho': 3, 'fixa_tamanho': False},
                'NUM_DOC': {'tipo': 'N', 'tamanho': 9, 'fixa_tamanho': False},
                'CHV_NFE': {'tipo': 'N', 'tamanho': 44, 'fixa_tamanho': True},
                'DT_DOC': {'tipo': 'D', 'tamanho': 8, 'fixa_tamanho': True},
                'DT_E_S': {'tipo': 'D', 'tamanho': 8, 'fixa_tamanho': True},
                'VL_DOC': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'IND_PGTO': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
                'VL_DESC': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_ABAT_NT': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_MERC': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'IND_FRT': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
                'VL_FRT': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_SEG': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_OUT_DA': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_BC_ICMS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_ICMS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_BC_ICMS_ST': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_ICMS_ST': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_IPI': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_PIS_ST': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_COFINS_ST': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
            }
            self.fieldnames = ('REG', 'IND_OPER', 'IND_EMIT', 'COD_PART', 'COD_MOD', 'COD_SIT',
                               'SER', 'NUM_DOC', 'CHV_NFE', 'DT_DOC', 'DT_E_S', 'VL_DOC',
                               'IND_PGTO', 'VL_DESC', 'VL_ABAT_NT', 'VL_MERC', 'IND_FRT', 'VL_FRT',
                               'VL_SEG', 'VL_OUT_DA', 'VL_BC_ICMS', 'VL_ICMS', 'VL_BC_ICMS_ST',
                               'VL_ICMS_ST', 'VL_IPI', 'VL_PIS', 'VL_COFINS', 'VL_PIS_ST',
                               'VL_COFINS_ST')
            self.formato = self.get_formato()

    class registro_C110(TrackedAttributesClass):
        """
        REGISTRO C110: COMPLEMENTO DO DOCUMENTO - INFORMAÇÃO COMPLEMENTAR
        DA NOTA FISCAL (CÓDIGOS 01, 1B, 04 e 55)
        Este registro tem por objetivo identificar os dados contidos no campo Informações Complementares da Nota Fiscal, que
        sejam de interesse do Fisco ou conforme disponha a legislação, e que estejam explicitamente citadas no documento
        Fiscal, tais como: forma de pagamento, local da prestação/execução do serviço, operação realizada com suspensão das
        contribuições sociais, etc.
        Não podem ser informados para um mesmo documento fiscal, dois ou mais registros com o mesmo conteúdo no campo
        COD_INF.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C110, self).__init__()
            self.REG = 'C110'         #Texto fixo contendo
            self.nivel_h = 4          #nível
            self.pai = 'C100'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.COD_INF = ''         #Código da informação complementar do documento fiscal (campo 02 do Registro 0450)
            self.TXT_COMPL = ''       #Descrição complementar do código de referência.
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_INF': {'tipo': 'C', 'tamanho': 6, 'fixa_tamanho': False},
                'TXT_COMPL': {'tipo': 'C', 'tamanho': 0, 'fixa_tamanho': False},

            }
            self.fieldnames = ('REG', 'COD_INF', 'TXT_COMPL')
            self.formato = self.get_formato()

    class registro_C111(TrackedAttributesClass):
        """
        REGISTRO C111: PROCESSO REFERENCIADO
        Este registro deve ser apresentado, obrigatoriamente, quando no campo – “Informações Complementares” da nota
        fiscal - constar a discriminação de processos referenciados no documento fiscal.
        Não podem ser informados dois ou mais registros com o mesmo conteúdo no campo NUM_PROC para um
        mesmo registro C110.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C111, self).__init__()
            self.REG = 'C111'         #Texto fixo contendo
            self.nivel_h = 4          #nível
            self.pai = 'C110'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.NUM_PROC = ''        #Identificação do processo ou ato concessório.
            self.IND_PROC = ''        #Indicador da origem do processo:0 - SEFAZ; 1 - Justiça Federal; ; 3 - Secretaria da Receita Federal do Brasil 9 - Outros.
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'NUM_PROC': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'IND_PROC': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},

            }
            self.fieldnames = ('REG', 'NUM_PROC', 'IND_PROC')
            self.formato = self.get_formato()

    class registro_C120(TrackedAttributesClass):
        """
        REGISTRO C120: COMPLEMENTO IMPORTAÇÃO (CÓDIGO 01) DO DOCUMENTO - OPERAÇÕES DE IMPORTAÇÃO (CÓDIGO 01)
        Este registro tem por objetivo informar detalhes das operações de importação, que estejam sendo documentadas pela nota
        fiscal escriturada no registro C100 (registro individualizado de documentos códigos 1, 1B, 04 e 55 - NF-e), quando o
        campo IND_OPER for igual a “0” (zero), indicando operação de entrada e que no registro filho C170 conste CST_PIS ou
        CST_COFINS gerador de crédito (CST 50 a 56), bem como conste no registro C170 CFOP próprio de operações de
        importação (CFOP iniciado em 3).
.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C120, self).__init__()
            self.REG = 'C120'         #Texto fixo contendo
            self.nivel_h = 4          #nível
            self.pai = 'C100'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.COD_DOC_IMP = ''     #Documento de importação: 0 – Declaração de Importação; 1 – Declaração Simplificada de Importação.
            self.NUM_DOC_IMP = ''    #Número do documento de Importação.
            self.VL_PIS_IMP = ''         #Valor pago de PIS na importação
            self.VL_COFINS_IMP = ''      #Valor pago de COFINS na importação
            self.NUM_ACDRAW = ''      #Número do Ato Concessório do regime Drawback
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_DOC_IMP': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
                'NUM_DOC_IMP': {'tipo': 'C', 'tamanho': 10, 'fixa_tamanho': False},
                'VL_PIS_IMP': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_COFINS_IMP': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'NUM_ACDRAW': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'COD_DOC_IMP', 'NUM_DOC_IMP', 'VL_PIS_IMP', 'VL_COFINS_IMP',
                               'NUM_ACDRAW')
            self.formato = self.get_formato()

    class registro_C170(TrackedAttributesClass):
        """
        REGISTRO C170: COMPLEMENTO DO DOCUMENTO - ITENS DO DOCUMENTO (CÓDIGOS 01, 1B, 04 e 55)
        Registro obrigatório para discriminar os itens da nota fiscal (mercadorias e/ou serviços constantes em notas conjugadas),
        inclusive em operações de entrada de mercadorias acompanhada de Nota Fiscal Eletrônica (NF-e) de emissão de
        terceiros.
        Não podem ser informados para um mesmo documento fiscal, dois ou mais registros com o mesmo conteúdo no campo
        NUM_ITEM.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C170, self).__init__()
            self.REG = 'C170'         #Texto fixo contendo
            self.nivel_h = 4          #nível
            self.pai = 'C100'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.NUM_ITEM = ''        #Número sequencial do item no documento fiscal
            self.COD_ITEM = ''        #Código do item (campo 02 do Registro 0200)
            self.DESCR_COMPL = ''     #Descrição complementar do item como adotado no documento fiscal
            self.QTD = ''             #Quantidade do item
            self.UNID = ''            #Unidade do item (Campo 02 do registro 0190)
            self.VL_ITEM = ''         #Valor total do item (mercadorias ou serviços)
            self.VL_DESC = ''         #Valor do desconto comercial
            self.IND_MOV = ''         #Movimentação física do ITEM/PRODUTO:0. SIM 1. NÃO
            self.CST_ICMS = ''        #Código da Situação Tributária referente ao ICMS, conforme a Tabela indicada no item 4.3.1
            self.CFOP = ''            #Código Fiscal de Operação e Prestação
            self.COD_NAT = ''         #Código da natureza da operação (campo 02 do Registro 0400)
            self.VL_BC_ICMS = ''      #Valor da base de cálculo do ICMS
            self.ALIQ_ICMS = ''       #Alíquota do ICMS
            self.VL_ICMS = ''         #Valor do ICMS creditado/debitado
            self.VL_BC_ICMS_ST = ''   #Valor da base de cálculo referente à substituição tributária
            self.ALIQ_ST = ''         #Alíquota do ICMS da substituição tributária na unidade da federação de destino
            self.VL_ICMS_ST = ''      #Valor do ICMS referente à substituição tributária
            self.IND_APUR = ''        #Indicador de período de apuração do IPI: 0 - Mensal; 1 - Decendial
            self.CST_IPI = ''         #Código da Situação Tributária referente ao IPI, conforme a Tabela indicada no item 4.3.2.
            self.COD_ENQ = ''         #Código de enquadramento legal do IPI, conforme tabela indicada no item 4.5.3.
            self.VL_BC_IPI = ''       #Valor da base de cálculo do IPI
            self.ALIQ_IPI = ''        #Alíquota do IPI
            self.VL_IPI = ''          #Valor do IPI creditado/debitado
            self.CST_PIS = ''         #Código da Situação Tributária referente ao PIS.
            self.VL_BC_PIS = ''       #Valor da base de cálculo do PIS
            self.ALIQ_PIS = ''        #Alíquota do PIS (em percentual)
            self.QUANT_BC_PIS = ''    #Quantidade – Base de cálculo PIS
            self.ALIQ_PIS_QUANT = ''        #Alíquota do PIS (em reais)
            self.VL_PIS = ''          #Valor do PIS
            self.CST_COFINS = ''      #Código da Situação Tributária referente ao COFINS.
            self.VL_BC_COFINS = ''    #Valor da base de cálculo da COFINS
            self.ALIQ_COFINS = ''     # Alíquota do COFINS (em percentual)
            self.QUANT_BC_COFINS = '' #Quantidade – Base de cálculo COFINS
            self.ALIQ_COFINS_QUANT = ''     #Alíquota da COFINS (em reais)
            self.VL_COFINS = ''       #Valor da COFINS
            self.COD_CTA = ''         #Código da conta analítica contábil debitada/creditada
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'NUM_ITEM': {'tipo': 'N', 'tamanho': 3, 'fixa_tamanho': False},
                'COD_ITEM': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'DESCR_COMPL': {'tipo': 'C', 'tamanho': 0, 'fixa_tamanho': False},
                'QTD': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 5},
                'UNID': {'tipo': 'C', 'tamanho': 6, 'fixa_tamanho': False},
                'VL_ITEM': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_DESC': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'IND_MOV': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': False},
                'CST_ICMS': {'tipo': 'N', 'tamanho': 3, 'fixa_tamanho': True},
                'CFOP': {'tipo': 'N', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_NAT': {'tipo': 'C', 'tamanho': 10, 'fixa_tamanho': False},
                'VL_BC_ICMS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'ALIQ_ICMS': {'tipo': 'N', 'tamanho': 6, 'fixa_tamanho': False, 'decimal': 2},
                'VL_ICMS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_BC_ICMS_ST': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'ALIQ_ST': {'tipo': 'N', 'tamanho': 6, 'fixa_tamanho': False, 'decimal': 2},
                'VL_ICMS_ST': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'IND_APUR': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
                'CST_IPI': {'tipo': 'C', 'tamanho': 2, 'fixa_tamanho': False},
                'COD_ENQ': {'tipo': 'C', 'tamanho': 3, 'fixa_tamanho': False},
                'VL_BC_IPI': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'ALIQ_IPI': {'tipo': 'N', 'tamanho': 6, 'fixa_tamanho': False, 'decimal': 2},
                'VL_IPI': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'CST_PIS': {'tipo': 'N', 'tamanho': 2, 'fixa_tamanho': True},
                'VL_BC_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'ALIQ_PIS': {'tipo': 'N', 'tamanho': 8, 'fixa_tamanho': False, 'decimal': 4},
                'QUANT_BC_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 3},
                'ALIQ_PIS_QUANT': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 4},
                'VL_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'CST_COFINS': {'tipo': 'N', 'tamanho': 2, 'fixa_tamanho': True},
                'VL_BC_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'ALIQ_COFINS': {'tipo': 'N', 'tamanho': 8, 'fixa_tamanho': False, 'decimal': 4},
                'QUANT_BC_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 3},
                'ALIQ_COFINS_QUANT': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 4},
                'VL_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'COD_CTA': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},

            }
            self.fieldnames = ('REG', 'NUM_ITEM', 'COD_ITEM', 'DESCR_COMPL', 'QTD', 'UNID',
                               'VL_ITEM', 'VL_DESC', 'IND_MOV', 'CST_ICMS', 'CFOP', 'COD_NAT',
                               'VL_BC_ICMS', 'ALIQ_ICMS', 'VL_ICMS', 'VL_BC_ICMS_ST', 'ALIQ_ST',
                               'VL_ICMS_ST', 'IND_APUR', 'CST_IPI', 'COD_ENQ', 'VL_BC_IPI',
                               'ALIQ_IPI', 'VL_IPI', 'CST_PIS', 'VL_BC_PIS', 'ALIQ_PIS',
                               'QUANT_BC_PIS', 'ALIQ_PIS_QUANT', 'VL_PIS', 'CST_COFINS',
                               'VL_BC_COFINS', 'ALIQ_COFINS', 'QUANT_BC_COFINS',
                               'ALIQ_COFINS_QUANT', 'VL_COFINS', 'COD_CTA')
            self.formato = self.get_formato()

    class registro_C175(TrackedAttributesClass):
        """
        Registro C175: Registro Analítico do Documento (Código 65)
        Este registro tem por objetivo representar a escrituração da NFC-e, código 65, os
        documentos fiscais totalizados por CST PIS, CST Cofins, CFOP, alíquota de PIS e alíquota
        da Cofins. Trata-se de registro com procedimento de escrituração similar ao adotado para
        o registro C190 da EFD-ICMS/IPI.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C175, self).__init__()
            self.REG = 'C175'            # Texto fixo contendo
            self.nivel_h = 4             # nível
            self.pai = 'C100'
            self.ocorrencia = 'N'        # ocorrência por arquivo
            self.CFOP = ''               # Código fiscal de operação e prestação
            self.VL_OPR = ''             # Valor da operação na combinação de CFOP, CST e alíquotas
            self.VL_DESC = ''            # Valor do desconto comercial / exclusão da base de cálculo
            self.CST_PIS = ''            # Código da Situação Tributária referente ao PIS/PASEP
            self.VL_BC_PIS = ''          # Valor da base de cálculo do PIS/PASEP (em valor)
            self.ALIQ_PIS = ''           # Alíquota do PIS/PASEP (em percentual)
            self.QUANT_BC_PIS = ''       # Base de cálculo PIS/PASEP (em quantidade)
            self.ALIQ_PIS_QUANT = ''     # ALíquota do PIS (em reais)
            self.VL_PIS = ''             # Valor do PIS/PASEP
            self.CST_COFINS = ''         # Código da Situação Tributária referente a COFINS
            self.VL_BC_COFINS = ''       # Valor da base de cálculo dA COFINS (em valor)
            self.ALIQ_COFINS = ''        # Alíquota da COFINS (em percentual)
            self.QUANT_BC_COFINS = ''    # Base de cálculo COFINS (em quantidade)
            self.ALIQ_COFINS_QUANT = ''  # ALíquota da COFINS (em reais)
            self.VL_COFINS = ''          # Valor da COFINS
            self.COD_CTA = ''            # Código da conta analítica contábil debitada/creditada
            self.INFO_COMPL = ''         # Informação complementar
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'CFOP': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'VL_OPR': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_DESC': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'CST_PIS': {'tipo': 'C', 'tamanho': 2, 'fixa_tamanho': True},
                'VL_BC_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'ALIQ_PIS': {'tipo': 'N', 'tamanho': 8, 'fixa_tamanho': True, 'decimal': 4},
                'QUANT_BC_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 3},
                'ALIQ_PIS_QUANT': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 4},
                'VL_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'CST_COFINS': {'tipo': 'C', 'tamanho': 2, 'fixa_tamanho': True},
                'VL_BC_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'ALIQ_COFINS': {'tipo': 'N', 'tamanho': 8, 'fixa_tamanho': True, 'decimal': 4},
                'QUANT_BC_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 3},
                'ALIQ_COFINS_QUANT': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 4},
                'VL_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'COD_CTA': {'tipo': 'C', 'tamanho': 255, 'fixa_tamanho': True},
                'INFO_COMPL': {'tipo': 'C', 'tamanho': 0, 'fixa_tamanho': False},
            }
            self.fieldnames = (
                'REG', 'CFOP', 'VL_OPR', 'VL_DESC', 'CST_PIS', 'VL_BC_PIS', 'ALIQ_PIS',
                'QUANT_BC_PIS', 'ALIQ_PIS_QUANT', 'VL_PIS', 'CST_COFINS', 'VL_BC_COFINS',
                'ALIQ_COFINS', 'QUANT_BC_COFINS', 'ALIQ_COFINS_QUANT', 'VL_COFINS', 'COD_CTA',
                'INFO_COMPL')
            self.formato = self.get_formato()


    class registro_C180(TrackedAttributesClass):
        """
        REGISTRO C180: CONSOLIDAÇÃO DE NOTAS FISCAIS ELETRÔNICAS EMITIDAS
        PELA PESSOA JURÍDICA (CÓDIGO 55) – OPERAÇÕES DE VENDAS
        Este registro deve ser preenchido para consolidar as operações de vendas realizadas pela pessoa jurídica, por item
        vendido (Registro 0200), mediante emissão de NF-e (Modelo 55), no período da escrituração.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C180, self).__init__()
            self.REG = 'C180'         #Texto fixo contendo
            self.nivel_h = 3          #nível
            self.pai = 'C001'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.COD_MOD = ''
            self.DT_DOC_INI = ''
            self.DT_DOC_FIN = ''
            self.COD_ITEM = ''
            self.COD_NCM = ''
            self.EX_IPI = ''
            self.VL_TOT_ITEM = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_MOD': {'tipo': 'C', 'tamanho': 2, 'fixa_tamanho': True},
                'DT_DOC_INI': {'tipo': 'D', 'tamanho': 8, 'fixa_tamanho': True},
                'DT_DOC_FIN': {'tipo': 'D', 'tamanho': 8, 'fixa_tamanho': True},
                'COD_ITEM': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'COD_NCM': {'tipo': 'C', 'tamanho': 8, 'fixa_tamanho': True},
                'EX_IPI': {'tipo': 'C', 'tamanho': 3, 'fixa_tamanho': False},
                'VL_TOT_ITEM ': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
            }
            self.fieldnames = ('REG', 'COD_MOD', 'DT_DOC_INI', 'DT_DOC_FIN', 'COD_ITEM', 'COD_NCM',
                               'EX_IPI', 'VL_TOT_ITEM')
            self.formato = self.get_formato()

    class registro_C181(TrackedAttributesClass):
        """
        REGISTRO C181: DETALHAMENTO DA CONSOLIDAÇÃO – OPERAÇÕES DE VENDAS  – PIS/PASEP
        Registro obrigatório, para fins de detalhamento por CST, CFOP e Alíquotas, dos valores consolidados de PIS/Pasep
        referentes a cada item objeto de venda por Nota Fiscal Eletrônica – NF-e.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C181, self).__init__()
            self.REG = 'C181'         #Texto fixo contendo
            self.nivel_h = 4          #nível
            self.pai = 'C180'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.CST_PIS = ''
            self.CFOP = ''
            self.VL_ITEM = ''
            self.VL_DESC = ''
            self.VL_BC_PIS = ''
            self.ALIQ_PIS = ''
            self.QUANT_BC_PIS = ''
            self.ALIQ_PIS_QUANT = ''
            self.VL_PIS = ''
            self.COD_CTA = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'CST_PIS': {'tipo': 'N', 'tamanho': 2, 'fixa_tamanho': True},
                'CFOP': {'tipo': 'N', 'tamanho': 4, 'fixa_tamanho': True},
                'VL_ITEM': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_DESC': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_BC_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'ALIQ_PIS': {'tipo': 'N', 'tamanho': 8, 'fixa_tamanho': False, 'decimal': 4},
                'QUANT_BC_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 3},
                'ALIQ_PIS_QUANT': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 4},
                'VL_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'COD_CTA': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'CST_PIS', 'CFOP', 'VL_ITEM', 'VL_DESC', 'VL_BC_PIS',
                               'ALIQ_PIS', 'QUANT_BC_PIS', 'ALIQ_PIS_QUANT', 'VL_PIS', 'COD_CTA')
            self.formato = self.get_formato()

    class registro_C185(TrackedAttributesClass):
        """
        REGISTRO C185: DETALHAMENTO DA CONSOLIDAÇÃO – OPERAÇÕES DE VENDAS – COFINS
        Registro obrigatório, para fins de detalhamento por CST, CFOP e Alíquotas, dos valores consolidados da Cofins
        referentes a cada item objeto de venda por Nota Fiscal Eletrônica – NF-e.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C185, self).__init__()
            self.REG = 'C185'         #Texto fixo contendo
            self.nivel_h = 4          #nível
            self.pai = 'C181'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.CST_COFINS = ''
            self.CFOP = ''
            self.VL_ITEM = ''
            self.VL_DESC = ''
            self.VL_BC_COFINS = ''
            self.ALIQ_COFINS = ''
            self.QUANT_BC_COFINS = ''
            self.ALIQ_COFINS_QUANT = ''
            self.VL_COFINS = ''
            self.COD_CTA = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'CST_COFINS': {'tipo': 'N', 'tamanho': 2, 'fixa_tamanho': True},
                'CFOP': {'tipo': 'N', 'tamanho': 4, 'fixa_tamanho': True},
                'VL_ITEM': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_DESC': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_BC_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'ALIQ_COFINS': {'tipo': 'N', 'tamanho': 8, 'fixa_tamanho': False, 'decimal': 4},
                'QUANT_BC_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 3},
                'ALIQ_PIS_QUANT': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 4},
                'VL_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'COD_CTA': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'CST_COFINS', 'CFOP', 'VL_ITEM', 'VL_DESC', 'VL_BC_COFINS',
                               'ALIQ_COFINS', 'QUANT_BC_COFINS', 'ALIQ_COFINS_QUANT', 'VL_COFINS', 'COD_CTA')
            self.formato = self.get_formato()

    class registro_C188(TrackedAttributesClass):
        """
        REGISTRO C188: PROCESSO REFERENCIADO
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C188, self).__init__()
            self.REG = 'C188'         #Texto fixo contendo
            self.nivel_h = 4          #nível
            self.pai = 'C100'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.NUM_PROC = ''
            self.IND_PROC = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'NUM_PROC': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'IND_PROC': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},

            }
            self.fieldnames = ('REG', 'NUM_PROC', 'IND_PROC')
            self.formato = self.get_formato()

    class registro_C190(TrackedAttributesClass):
        """
        REGISTRO C190: CONSOLIDAÇÃO DE NOTAS FISCAIS ELETRÔNICAS (CÓDIGO 55) – OPERAÇÕES DE AQUISIÇÃO COM DIREITO A CRÉDITO, E OPERAÇÕES DE
        DEVOLUÇÃO DE COMPRAS E VENDAS.
        Este registro deve ser preenchido para consolidar as operações de aquisições ou devoluções de vendas realizadas pela
        pessoa jurídica, por item vendido (Registro 0200), mediante emissão de NF-e (Modelo 55), no período da escrituração,
        com direito à apuração de crédito
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C190, self).__init__()
            self.REG = 'C190'         #Texto fixo contendo
            self.nivel_h = 3          #nível
            self.pai = 'C100'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.COD_MOD = ''
            self.DT_REF_INI = ''
            self.DT_REF_FIN = ''
            self.COD_ITEM = ''
            self.COD_NCM = ''
            self.EX_IPI = ''
            self.VL_TOT_ITEM = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_MOD': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'DT_REF_INI': {'tipo': 'D', 'tamanho': 8, 'fixa_tamanho': True},
                'DT_REF_FIN': {'tipo': 'D', 'tamanho': 8, 'fixa_tamanho': True},
                'COD_ITEM': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'COD_NCM': {'tipo': 'C', 'tamanho': 8, 'fixa_tamanho': True},
                'EX_IPI': {'tipo': 'C', 'tamanho': 3, 'fixa_tamanho': False},
                'VL_TOT_ITEM ': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
            }
            self.fieldnames = ('REG', 'COD_MOD', 'DT_REF_INI', 'DT_REF_FIN', 'COD_ITEM', 'COD_NCM',
                               'EX_IPI', 'VL_TOT_ITEM')
            self.formato = self.get_formato()

    class registro_C191(TrackedAttributesClass):
        """
        REGISTRO C191: DETALHAMENTO DA CONSOLIDAÇÃO – OPERAÇÕES DE AQUISIÇÃO COM DIREITO A CRÉDITO, E OPERAÇÕES DE DEVOLUÇÃO DE
        COMPRAS E VENDAS – PIS/PASEP
        Registro obrigatório, para fins de detalhamento por fornecedor, CST, CFOP e Alíquotas, dos valores consolidados de
        PIS/Pasep referentes a cada item objeto de aquisição e/ou devolução, por Nota Fiscal Eletrônica – NF-e.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C191, self).__init__()
            self.REG = 'C191'         #Texto fixo contendo
            self.nivel_h = 4          #nível
            self.pai = 'C100'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.CNPJ_CPF_PART = ''
            self.CST_PIS = ''
            self.CFOP = ''
            self.VL_ITEM = ''
            self.VL_DESC = ''
            self.VL_BC_PIS = ''
            self.ALIQ_PIS = ''
            self.QUANT_BC_PIS = ''
            self.ALIQ_PIS_QUANT = ''
            self.VL_PIS = ''
            self.COD_CTA = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'CNPJ_CPF_PART': {'tipo': 'C', 'tamanho': 14, 'fixa_tamanho': False},
                'CST_PIS': {'tipo': 'N', 'tamanho': 2, 'fixa_tamanho': True},
                'CFOP': {'tipo': 'N', 'tamanho': 4, 'fixa_tamanho': True},
                'VL_ITEM': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_DESC': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_BC_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'ALIQ_PIS': {'tipo': 'N', 'tamanho': 8, 'fixa_tamanho': False, 'decimal': 4},
                'QUANT_BC_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 3},
                'ALIQ_PIS_QUANT': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 4},
                'VL_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'COD_CTA': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'CNPJ_CPF_PART', 'CST_PIS', 'CFOP', 'VL_ITEM', 'VL_DESC',
                               'VL_BC_PIS', 'ALIQ_PIS', 'QUANT_BC_PIS', 'ALIQ_PIS_QUANT', 'VL_PIS',
                               'COD_CTA')
            self.formato = self.get_formato()

    class registro_C195(TrackedAttributesClass):
        """
        REGISTRO C195: DETALHAMENTO DA CONSOLIDAÇÃO - OPERAÇÕES DE AQUISIÇÃO COM DIREITO A CRÉDITO, E OPERAÇÕES DE DEVOLUÇÃO DE
        COMPRAS E VENDAS – COFINS
        Registro obrigatório, para fins de detalhamento por fornecedor, CST, CFOP e Alíquotas, dos valores consolidados de
        Cofins referentes a cada item objeto de aquisição e/ou devolução, por Nota Fiscal Eletrônica – NF-e.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C195, self).__init__()
            self.REG = 'C195'         #Texto fixo contendo
            self.nivel_h = 4          #nível
            self.pai = 'C100'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.CNPJ_CPF_PART = ''
            self.CST_COFINS = ''
            self.CFOP = ''
            self.VL_ITEM = ''
            self.VL_DESC = ''
            self.VL_BC_COFINS = ''
            self.ALIQ_COFINS = ''
            self.QUANT_BC_COFINS = ''
            self.ALIQ_COFINS_QUANT = ''
            self.VL_COFINS = ''
            self.COD_CTA = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'CNPJ_CPF_PART': {'tipo': 'C', 'tamanho': 14, 'fixa_tamanho': False},
                'CST_COFINS': {'tipo': 'N', 'tamanho': 2, 'fixa_tamanho': True},
                'CFOP': {'tipo': 'N', 'tamanho': 4, 'fixa_tamanho': True},
                'VL_ITEM': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_DESC': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_BC_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'ALIQ_COFINS': {'tipo': 'N', 'tamanho': 8, 'fixa_tamanho': False, 'decimal': 4},
                'QUANT_BC_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 3},
                'ALIQ_PIS_QUANT': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 4},
                'VL_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'COD_CTA': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'CNPJ_CPF_PART', 'CST_COFINS', 'CFOP', 'VL_ITEM', 'VL_DESC',
                               'VL_BC_COFINS', 'ALIQ_COFINS', 'QUANT_BC_COFINS',
                               'ALIQ_COFINS_QUANT', 'VL_COFINS', 'COD_CTA')
            self.formato = self.get_formato()

    class registro_C198(TrackedAttributesClass):
        """
        REGISTRO C198: PROCESSO REFERENCIADO
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C198, self).__init__()
            self.REG = 'C198'         #Texto fixo contendo
            self.nivel_h = 4          #nível
            self.pai = 'C100'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.NUM_PROC = ''
            self.IND_PROC = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'NUM_PROC': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'IND_PROC': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},

            }
            self.fieldnames = ('REG', 'NUM_PROC', 'IND_PROC')
            self.formato = self.get_formato()

    class registro_C199(TrackedAttributesClass):
        """
        REGISTRO C199: COMPLEMENTO DO DOCUMENTO - OPERAÇÕES DE IMPORTAÇÃO (CÓDIGO 55)
        Este registro tem por objetivo informar detalhes das operações de importação, que estejam sendo documentadas de forma
        consolidada no registro C190 (registro consolidado das aquisições por NF-e, código 55), quando no Campo 03 dos
        registros C191 e C195 conste CST_PIS ou CST_COFINS gerador de crédito (CST 50 a 56) e, no Campo 04, conste
        CFOP próprio de operações de importação (CFOP iniciado em 3).

        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C199, self).__init__()
            self.REG = 'C199'         #Texto fixo contendo
            self.nivel_h = 4          #nível
            self.pai = 'C100'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.COD_DOC_IMP = ''     #Documento de importação: 0 – Declaração de Importação; 1 – Declaração Simplificada de Importação.
            self.NUM_DOC_IMP = ''    #Número do documento de Importação.
            self.VL_PIS_IMP = ''         #Valor pago de PIS na importação
            self.VL_COFINS_IMP = ''      #Valor pago de COFINS na importação
            self.NUM_ACDRAW = ''      #Número do Ato Concessório do regime Drawback
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_DOC_IMP': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
                'NUM_DOC_IMP': {'tipo': 'C', 'tamanho': 10, 'fixa_tamanho': False},
                'VL_PIS_IMP': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_COFINS_IMP': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'NUM_ACDRAW': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'COD_DOC_IMP', 'NUM_DOC_IMP', 'VL_PIS_IMP', 'VL_COFINS_IMP',
                               'NUM_ACDRAW')
            self.formato = self.get_formato()

    class registro_C380(TrackedAttributesClass):
        """
        REGISTRO C380: NOTA FISCAL DE VENDA A CONSUMIDOR (CÓDIGO 02) - CONSOLIDAÇÃO DE DOCUMENTOS EMITIDOS.
        No registro C380 e filhos deve a pessoa jurídica escriturar as notas fiscais de venda ao consumidor não emitidas por ECF
        (código 02), consolidando os valores dos documentos emitidos no período da escrituração.
        Nos registros filhos C381 (PIS/Pasep) e C385 (Cofins) devem ser detalhados os valores por CST, por item vendido e por
        alíquota, conforme o caso.
        Os valores de documentos fiscais cancelados não devem ser computados no valor total dos documentos (campo
        VL_DOC), nem nos registros filhos.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C380, self).__init__()
            self.REG = 'C380'         #Texto fixo contendo
            self.nivel_h = 3          #nível
            self.pai = 'C001'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.COD_MOD = ''
            self.DT_DOC_INI = ''
            self.DT_DOC_FIN = ''
            self.NUM_DOC_INI = ''
            self.NUM_DOC_FIN = ''
            self.VL_DOC = ''
            self.VL_DOC_CANC = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_DOC_IMP': {'tipo': 'C', 'tamanho': 2, 'fixa_tamanho': True},
                'DT_DOC_INI': {'tipo': 'D', 'tamanho': 8, 'fixa_tamanho': True},
                'DT_DOC_FIN': {'tipo': 'D', 'tamanho': 8, 'fixa_tamanho': True},
                'NUM_DOC_INI': {'tipo': 'N', 'tamanho': 6, 'fixa_tamanho': False},
                'NUM_DOC_FIN': {'tipo': 'N', 'tamanho': 6, 'fixa_tamanho': False},
                'VL_DOC': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_DOC_CANC': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
            }
            self.fieldnames = ('REG', 'COD_MOD', 'DT_DOC_INI', 'DT_DOC_FIN', 'NUM_DOC_INI',
                               'NUM_DOC_FIN', 'VL_DOC', 'VL_DOC_CANC')
            self.formato = self.get_formato()

    class registro_C381(TrackedAttributesClass):
        """
        REGISTRO C381: DETALHAMENTO DA CONSOLIDAÇÃO – PIS/PASEP
        Neste registro serão informados os valores consolidados de cada item constante nas notas fiscais de venda a
        consumidor – código 02, objeto de consolidação no Registro Pai C380. Deve ser gerado um registro para cada
        combinação de CST e alíquotas.

        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C381, self).__init__()
            self.REG = 'C381'         #Texto fixo contendo
            self.nivel_h = 4          #nível
            self.pai = 'C380'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.CST_PIS = ''
            self.COD_ITEM = ''
            self.VL_ITEM = ''
            self.VL_BC_PIS = ''
            self.ALIQ_PIS = ''
            self.QUANT_BC_PIS = ''
            self.ALIQ_PIS_QUANT = ''
            self.VL_PIS = ''
            self.COD_CTA = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'CST_PIS': {'tipo': 'N', 'tamanho': 2, 'fixa_tamanho': True},
                'COD_ITEM': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'VL_ITEM': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_DESC': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_BC_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'ALIQ_PIS': {'tipo': 'N', 'tamanho': 8, 'fixa_tamanho': False, 'decimal': 4},
                'QUANT_BC_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 3},
                'ALIQ_PIS_QUANT': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 4},
                'VL_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'COD_CTA': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'CST_PIS', 'COD_ITEM', 'VL_ITEM', 'VL_BC_PIS', 'ALIQ_PIS',
                               'QUANT_BC_PIS', 'ALIQ_PIS_QUANT', 'VL_PIS', 'COD_CTA')
            self.formato = self.get_formato()

    class registro_C385(TrackedAttributesClass):
        """
        REGISTRO C385: DETALHAMENTO DA CONSOLIDAÇÃO – COFINS
        Neste registro serão informados os valores consolidados de cada item constante nas notas fiscais de venda a
        consumidor – código 02, objeto de consolidação no Registro Pai C380. Deve ser gerado um registro para cada
        combinação de CST e alíquotas.


        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C385, self).__init__()
            self.REG = 'C385'         #Texto fixo contendo
            self.nivel_h = 4          #nível
            self.pai = 'C380'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.CST_COFINS = ''
            self.COD_ITEM = ''
            self.VL_ITEM = ''
            self.VL_BC_COFINS = ''
            self.ALIQ_COFINS = ''
            self.QUANT_BC_COFINS = ''
            self.ALIQ_COFINS_QUANT = ''
            self.VL_COFINS = ''
            self.COD_CTA = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'CST_COFINS': {'tipo': 'N', 'tamanho': 2, 'fixa_tamanho': True},
                'COD_ITEM': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'VL_ITEM': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_DESC': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_BC_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'ALIQ_COFINS': {'tipo': 'N', 'tamanho': 8, 'fixa_tamanho': False, 'decimal': 4},
                'QUANT_BC_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 3},
                'ALIQ_COFINS_QUANT': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 4},
                'VL_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'COD_CTA': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'CST_COFINS', 'COD_ITEM', 'VL_ITEM', 'VL_BC_COFINS',
                               'ALIQ_COFINS', 'QUANT_BC_COFINS', 'ALIQ_COFINS_QUANT', 'VL_COFINS',
                               'COD_CTA')
            self.formato = self.get_formato()

    class registro_C395(TrackedAttributesClass):
        """
        REGISTRO C395: NOTAS FISCAIS DE VENDA A CONSUMIDOR (CÓDIGOS 02, 2D, 2E e
        59) – AQUISIÇÕES/ENTRADAS COM CRÉDITO.
        No Registro C395 a pessoa jurídica poderá escriturar eventuais aquisições com direito a crédito (aquisição de bens a
        serem utilizados como insumos, por exemplo) cuja operação esteja documentada por nota fiscal de venda a consumidor.
        No Registro filho C396 deve ser detalhado os dados fiscais necessários para a apuração dos créditos de PIS/Pasep e de
        Cofins.

        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C395, self).__init__()
            self.REG = 'C395'         #Texto fixo contendo
            self.nivel_h = 3          #nível
            self.pai = 'C001'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.COD_MOD = ''
            self.COD_PART = ''
            self.SER = ''
            self.SUB_SER = ''
            self.NUM_DOC = ''
            self.DT_DOC = ''
            self.VL_DOC = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_MOD': {'tipo': 'C', 'tamanho': 2, 'fixa_tamanho': True},
                'COD_PART': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'SER': {'tipo': 'C', 'tamanho': 3, 'fixa_tamanho': False},
                'SUB_SER': {'tipo': 'C', 'tamanho': 3, 'fixa_tamanho': False},
                'NUM_DOC': {'tipo': 'C', 'tamanho': 6, 'fixa_tamanho': False},
                'DT_DOC': {'tipo': 'D', 'tamanho': 8, 'fixa_tamanho': True},
                'VL_DOC': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
            }
            self.fieldnames = ('REG', 'COD_MOD', 'COD_PART', 'SER', 'SUB_SER', 'NUM_DOC', 'DT_DOC',
                               'VL_DOC')
            self.formato = self.get_formato()

    class registro_C396(TrackedAttributesClass):
        """
        REGISTRO C396: ITENS DO DOCUMENTO (CÓDIGOS 02, 2D, 2E e 59) – AQUISIÇÕES/ENTRADAS COM CRÉDITO
        Deve ser informado neste registro as informações referentes aos itens das notas fiscais de vendas a consumidor
        relacionadas no Registro Pai C395, necessárias para a apuração, por item do documento fiscal, dos créditos de PIS/Pasep
        e de Cofins.
        Deve ser gerado um registro para cada item constante na nota fiscal de venda a consumidor relacionada em C395.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C396, self).__init__()
            self.REG = 'C396'         #Texto fixo contendo
            self.nivel_h = 4          #nível
            self.pai = 'C395'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.COD_ITEM = ''
            self.VL_ITEM = ''
            self.VL_DESC = ''
            self.NAT_BC_CRED = ''
            self.CST_PIS = ''
            self.VL_BC_PIS = ''
            self.ALIQ_PIS = ''
            self.VL_PIS = ''
            self.CST_COFINS = ''
            self.VL_BC_COFINS = ''
            self.ALIQ_COFINS = ''
            self.VL_COFINS = ''
            self.COD_CTA = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_ITEM': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'VL_ITEM': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_DESC': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'NAT_BC_CRED': {'tipo': 'C', 'tamanho': 2, 'fixa_tamanho': True},
                'CST_PIS': {'tipo': 'N', 'tamanho': 2, 'fixa_tamanho': True},
                'VL_BC_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'ALIQ_PIS': {'tipo': 'N', 'tamanho': 8, 'fixa_tamanho': False, 'decimal': 4},
                'VL_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'CST_COFINS': {'tipo': 'N', 'tamanho': 2, 'fixa_tamanho': True},
                'VL_BC_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'ALIQ_COFINS': {'tipo': 'N', 'tamanho': 8, 'fixa_tamanho': False, 'decimal': 4},
                'VL_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'COD_CTA': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'COD_ITEM', 'VL_ITEM', 'VL_DESC', 'NAT_BC_CRED', 'CST_PIS',
                               'VL_BC_PIS', 'ALIQ_PIS', 'VL_PIS', 'CST_COFINS', 'VL_BC_COFINS',
                               'ALIQ_COFINS', 'VL_COFINS', 'COD_CTA')
            self.formato = self.get_formato()

    class registro_C400(TrackedAttributesClass):
        """
        REGISTRO C400 - EQUIPAMENTO ECF (CÓDIGO 02 e 2D).
        Este registro tem por objetivo identificar os equipamentos de ECF e deve ser informado por todos os contribuintes
        que utilizem tais equipamentos na emissão de documentos fiscais.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C400, self).__init__()
            self.REG = 'C400'         #Texto fixo contendo
            self.nivel_h = 3          #nível
            self.pai = 'C001'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.COD_MOD = ''         #Código do modelo do documento conforme a Tabela 4.1.1
            self.ECF_MOD = ''         #Modelo do equipamento
            self.ECF_FAB = ''         #Número de série de fabricação do ECF
            self.ECF_CX = ''          #Número do caixa atribuído ao ECF
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_MOD': {'tipo': 'C', 'tamanho': 2, 'fixa_tamanho': True},
                'ECF_MOD': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'ECF_FAB': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'ECF_CX': {'tipo': 'N', 'tamanho': 3, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'COD_MOD', 'ECF_MOD', 'ECF_FAB', 'ECF_CX')
            self.formato = self.get_formato()

    class registro_C405(TrackedAttributesClass):
        """
        REGISTRO C405 - REDUÇÃO Z (CÓDIGO 02 e 2D).
        Este registro deve ser apresentado com as informações da Redução Z de cada equipamento em funcionamento na data das
        operações de venda à qual se refere a redução. Inclui todos os documentos fiscais totalizados na Redução Z, inclusive as
        operações de venda realizadas durante o período de tolerância do Equipamento ECF.

        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C405, self).__init__()
            self.REG = 'C405'         #Texto fixo contendo
            self.nivel_h = 4          #nível
            self.pai = 'C400'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.DT_DOC = ''          #Data do movimento a que se refere a Redução Z
            self.CRO = ''             #Posição do Contador de Reinício de Operação
            self.CRZ = ''             #Posição do Contador de Redução Z
            self.NUM_COO_FIN = ''     #Número do Contador de Ordem de Operação do último documento emitido no dia. (Número do COO na Redução Z)
            self.GT_FIN = ''          #Valor do Grande Total final
            self.VL_BRT = ''          #Valor da venda bruta
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'DT_DOC': {'tipo': 'D', 'tamanho': 8, 'fixa_tamanho': True},
                'CRO': {'tipo': 'N', 'tamanho': 6, 'fixa_tamanho': False},
                'CRZ': {'tipo': 'N', 'tamanho': 6, 'fixa_tamanho': False},
                'NUM_COO_FIN': {'tipo': 'N', 'tamanho': 6, 'fixa_tamanho': False},
                'GT_FIN': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_BRT': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
            }
            self.fieldnames = ('REG', 'DT_DOC', 'CRO', 'CRZ', 'NUM_COO_FIN', 'GT_FIN', 'VL_BRT')
            self.formato = self.get_formato()

    class registro_C481(TrackedAttributesClass):
        """
        REGISTRO C481: RESUMO DIÁRIO DE DOCUMENTOS EMITIDOS POR ECF –
        PIS/PASEP (CÓDIGOS 02 e 2D).
        Neste registro serão informados os valores consolidados por resumo diário, das informações relativas ao PIS/Pasep
        incidente sobre as vendas por ECF, por item vendido no período.
        Deve ser gerado um registro para cada item vendido, conforme o cadastramento efetuado em 0200. No caso de ocorrência
        de venda com CST distintos, deve ser gerado um registro para cada CST.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C481, self).__init__()
            self.REG = 'C481'         #Texto fixo contendo
            self.nivel_h = 5          #nível
            self.pai = 'C400'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.CST_PIS = ''
            self.VL_ITEM = ''
            self.VL_BC_PIS = ''
            self.ALIQ_PIS = ''
            self.QUANT_BC_PIS = ''
            self.ALIQ_PIS_QUANT = ''
            self.VL_PIS = ''
            self.COD_ITEM = ''
            self.COD_CTA = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'CST_PIS': {'tipo': 'N', 'tamanho': 2, 'fixa_tamanho': True},
                'VL_ITEM': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_BC_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'ALIQ_PIS': {'tipo': 'N', 'tamanho': 8, 'fixa_tamanho': False, 'decimal': 4},
                'QUANT_BC_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 3},
                'ALIQ_PIS_QUANT': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 4},
                'VL_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'COD_ITEM': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'COD_CTA': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'CST_PIS', 'VL_ITEM', 'VL_BC_PIS', 'ALIQ_PIS', 'QUANT_BC_PIS',
                               'ALIQ_PIS_QUANT', 'VL_PIS', 'COD_ITEM', 'COD_CTA')
            self.formato = self.get_formato()

    class registro_C485(TrackedAttributesClass):
        """
        REGISTRO C485: RESUMO DIÁRIO DE DOCUMENTOS EMITIDOS POR ECF –
        COFINS (CÓDIGOS 02 e 2D)
        Neste registro serão informados os valores consolidados por resumo diário, das informações relativas a Cofins
        incidente sobre as vendas por ECF, por item vendido no período.
        Deve ser gerado um registro para cada item vendido, conforme o cadastram
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C485, self).__init__()
            self.REG = 'C485'         #Texto fixo contendo
            self.nivel_h = 5          #nível
            self.pai = 'C400'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.CST_COFINS = ''
            self.VL_ITEM = ''
            self.VL_BC_COFINS = ''
            self.ALIQ_COFINS = ''
            self.QUANT_BC_COFINS = ''
            self.ALIQ_COFINS_QUANT = ''
            self.VL_COFINS = ''
            self.COD_ITEM = ''
            self.COD_CTA = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'CST_COFINS': {'tipo': 'N', 'tamanho': 2, 'fixa_tamanho': True},
                'VL_ITEM': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_BC_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'ALIQ_COFINS': {'tipo': 'N', 'tamanho': 8, 'fixa_tamanho': False, 'decimal': 4},
                'QUANT_BC_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 3},
                'ALIQ_COFINS_QUANT': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 4},
                'VL_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'COD_ITEM': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'COD_CTA': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'CST_COFINS', 'VL_ITEM', 'VL_BC_COFINS', 'ALIQ_COFINS',
                               'QUANT_BC_COFINS', 'ALIQ_COFINS_QUANT', 'VL_COFINS', 'COD_ITEM',
                               'COD_CTA')
            self.formato = self.get_formato()

    class registro_C489(TrackedAttributesClass):
        """
        REGISTRO C489: PROCESSO REFERENCIADO
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C489, self).__init__()
            self.REG = 'C489'         #Texto fixo contendo
            self.nivel_h = 4          #nível
            self.pai = 'C400'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.NUM_PROC = ''
            self.IND_PROC = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'NUM_PROC': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'IND_PROC': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
            }
            self.fieldnames = ('REG', 'NUM_PROC', 'IND_PROC')
            self.formato = self.get_formato()

    class registro_C490(TrackedAttributesClass):
        """
        REGISTRO C490: CONSOLIDAÇÃO DE DOCUMENTOS EMITIDOS POR ECF (CÓDIGOS 02, 2D e 59)
        Registro para a escrituração consolidada das vendas do período, mediante a emissão de cupom fiscal por ECF,
        relacionando as operações por item de produto. A escrituração de forma consolidada das operações de vendas
        mediante cupom fiscal neste registro substitui a escrituração das vendas por ECF constante do
        registro C400.Nos registros filhos C491 (PIS/Pasep) e C495 (Cofins) devem ser detalhados os valores por CST, por
        item vendido e por alíquota, conforme o caso.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C490, self).__init__()
            self.REG = 'C490'         #Texto fixo contendo
            self.nivel_h = 3          #nível
            self.pai = 'C001'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.DT_DOC_INI = ''
            self.DT_DOC_FIN = ''
            self.COD_MOD = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'DT_DOC_INI': {'tipo': 'D', 'tamanho': 8, 'fixa_tamanho': True},
                'DT_DOC_FIN': {'tipo': 'D', 'tamanho': 8, 'fixa_tamanho': True},
                'COD_MOD': {'tipo': 'C', 'tamanho': 2, 'fixa_tamanho': True},
            }
            self.fieldnames = ('REG', 'DT_DOC_INI', 'DT_DOC_FIN', 'COD_MOD')
            self.formato = self.get_formato()

    class registro_C491(TrackedAttributesClass):
        """
            REGISTRO C491: DETALHAMENTO DA CONSOLIDAÇÃO DE DOCUMENTOS
            EMITIDOS POR ECF (CÓDIGOS 02, 2D e 59) – PIS/PASEP
            """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C491, self).__init__()
            self.REG = 'C491'         #Texto fixo contendo
            self.nivel_h = 3          #nível
            self.pai = 'C405'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.COD_ITEM = ''        #Código da Situação Tributária, conforme a  Tabela indicada no item 4.3.1
            self.CST_PIS = ''
            self.CFOP = ''
            self.VL_ITEM = ''
            self.VL_BC_PIS = ''
            self.ALIQ_PIS = ''
            self.QUANT_BC_PIS = ''
            self.ALIQ_PIS_QUANT = ''
            self.VL_PIS = ''
            self.COD_CTA = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_ITEM ': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'CST_PIS': {'tipo': 'N', 'tamanho': 2, 'fixa_tamanho': True},
                'CFOP': {'tipo': 'N', 'tamanho': 4, 'fixa_tamanho': True},
                'VL_ITEM': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_BC_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'ALIQ_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 4},
                'QUANT_BC_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 3},
                'ALIQ_PIS_QUANT': {'tipo': 'N', 'tamanho': 8, 'fixa_tamanho': False, 'decimal': 4},
                'VL_PIS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'COD_CTA': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'COD_ITEM', 'CST_PIS', 'CFOP', 'VL_ITEM', 'VL_BC_PIS',
                               'ALIQ_PIS', 'QUANT_BC_PIS', 'ALIQ_PIS_QUANT', 'VL_PIS', 'COD_CTA')
            self.formato = self.get_formato()

    class registro_C495(TrackedAttributesClass):
        """
              REGISTRO C495: DETALHAMENTO DA CONSOLIDAÇÃO DE DOCUMENTOS
             EMITIDOS POR ECF (CÓDIGOS 02, 2D e 59) – COFINS
             """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C495, self).__init__()
            self.REG = 'C495'         #Texto fixo contendo
            self.nivel_h = 4          #nível
            self.pai = 'C001'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.COD_ITEM = ''
            self.CST_COFINS = ''
            self.CFOP = ''
            self.VL_ITEM = ''
            self.VL_BC_COFINS = ''
            self.ALIQ_COFINS = ''
            self.QUANT_BC_COFINS = ''
            self.ALIQ_COFINS_QUANT = ''
            self.VL_COFINS = ''
            self.COD_CTA = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_ITEM': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
                'CST_COFINS': {'tipo': 'N', 'tamanho': 2, 'fixa_tamanho': True},
                'CFOP': {'tipo': 'N', 'tamanho': 4, 'fixa_tamanho': True},
                'VL_ITEM': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'VL_BC_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'ALIQ_COFINS': {'tipo': 'N', 'tamanho': 8, 'fixa_tamanho': False, 'decimal': 4},
                'QUANT_BC_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 3},
                'ALIQ_COFINS_QUANT': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 4},
                'VL_COFINS': {'tipo': 'N', 'tamanho': 0, 'fixa_tamanho': False, 'decimal': 2},
                'COD_CTA': {'tipo': 'C', 'tamanho': 60, 'fixa_tamanho': False},
            }
            self.fieldnames = ('REG', 'COD_ITEM', 'CST_COFINS', 'CFOP', 'VL_ITEM', 'VL_BC_COFINS',
                               'ALIQ_COFINS', 'QUANT_BC_COFINS', 'ALIQ_COFINS_QUANT', 'VL_COFINS',
                               'COD_CTA')
            self.formato = self.get_formato()

    class registro_C499(TrackedAttributesClass):
        '''REGISTRO C499: PROCESSO REFERENCIADO'''
        _order = []

        def __init__(self):
            super(bloco_c.registro_C499, self).__init__()
            self.REG = 'C499'         #Texto fixo contendo
            self.nivel_h = 4          #nível
            self.pai = 'C001'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.NUM_PROC = ''
            self.IND_PROC = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'NUM_PROC': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'IND_PROC': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
            }
            self.fieldnames = ('REG', 'NUM_PROC', 'IND_PROC')
            self.formato = self.get_formato()

    class registro_C500(TrackedAttributesClass):
        """
        REGISTRO C500: NOTA FISCAL/CONTA DE ENERGIA ELÉTRICA (CÓDIGO 06),NOTA FISCAL/CONTA DE FORNECIMENTO D'ÁGUA CANALIZADA (CÓDIGO 29)
        E NOTA FISCAL CONSUMO FORNECIMENTO DE GÁS (CÓDIGO 28).
        Este registro deve ser apresentado, nas operações de saída, pelos contribuintes do segmento de energia elétrica e
        não obrigadas ao Convênio ICMS 115/03, pelos contribuintes do segmento de fornecimento de gás e, nas operações de
        entrada, por todos os contribuintes adquirentes.
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C500, self).__init__()
            self.REG = 'C500'         #Texto fixo contendo
            self.nivel_h = 2          #nível
            self.pai = 'C001'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.COD_PART = ''
            self.COD_MOD = ''
            self.COD_SIT = ''
            self.SER = ''
            self.SUB = ''
            self.NUM_DOC = ''
            self.DT_DOC = ''
            self.DT_ENT = ''
            self.VL_DOC = ''
            self.VL_ICMS = ''
            self.COD_INF = ''
            self.VL_PIS = ''
            self.VL_COFINS = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_PART': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'COD_MOD': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
                'COD_SIT': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
                'SER': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
                'SUB': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
                'NUM_DOC': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
                'DT_DOC': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
                'DT_ENT': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
                'VL_DOC': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
                'VL_ICMS': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
                'COD_INF': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
                'VL_PIS': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
                'VL_COFINS': {'tipo': 'C', 'tamanho': 1, 'fixa_tamanho': True},
            }

        #                todo:conferir os dados do atributo  self.parametros para este registro c500
            self.fieldnames = ('REG', 'COD_PART', 'COD_MOD', 'COD_SIT', 'SER', 'SUB', 'NUM_DOC', 
                               'DT_DOC', 'DT_ENT', 'VL_DOC', 'VL_ICMS', 'COD_INF', 'VL_PIS', 
                               'VL_COFINS')
            self.formato = self.get_formato()

    class registro_C501(TrackedAttributesClass):
        """
            REGISTRO C501: COMPLEMENTO DA OPERAÇÃO (CÓDIGOS 06, 28 e 29) – PIS/PASEP
            Neste registro devem ser detalhadas as informações relativas à apuração do crédito de PIS/Pasep, referentes ao
            documento fiscal escriturado no Registro Pai C500. Deve ser escriturado um registro C501 para cada item (fornecimento
            dágua canalizada, de energia elétrica ou de gás) cuja operação dê direito a crédito, pelo seu valor total ou parcial.G
            Caso em relação a um mesmo item venha a ocorrer tratamentos tributários diversos (mais de um CST), deve a pessoa
            jurídica informar um registro C501 para cada CST
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C501, self).__init__()
            self.REG = 'C501'         #Texto fixo contendo
            self.nivel_h = 3          #nível
            self.pai = 'C500'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.CST_PIS = ''
            self.VL_ITEM = ''
            self.NAT_BC_CRED = ''
            self.VL_BC_PIS = ''
            self.ALIQ_PIS = ''
            self.VL_PIS = ''
            self.COD_CTA = ''
            self.parametros = ''
            #todo: terminar de preencher parametros c501
            self.fieldnames = ('REG', 'CST_PIS', 'VL_ITEM', 'NAT_BC_CRED', 'VL_BC_PIS', 'ALIQ_PIS', 
                               'VL_PIS', 'COD_CTA')
            self.formato = self.get_formato()

    class registro_C505(TrackedAttributesClass):
        """
            REGISTRO C505: COMPLEMENTO DA OPERAÇÃO (CÓDIGOS 06, 28 e 29) – COFINS
            Neste registro devem ser detalhadas as informações relativas à apuração do crédito de COFINS, referentes ao documento
            fiscal escriturado no Registro Pai C500. Deve ser escriturado um registro C505 para cada item (fornecimento dágua
            canalizada, de energia elétrica ou de gás) cuja operação dê direito a crédito, pelo seu valor total ou parcial.
            Caso em relação a um mesmo item venha a ocorrer tratamentos tributários diversos (mais de um CST), deve a pessoa
            jurídica informar um registro C505 para cada CST.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C505, self).__init__()
            self.REG = 'C505'         #Texto fixo contendo
            self.nivel_h = 3          #nível
            self.pai = 'C500'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.CST_COFINS = ''
            self.VL_ITEM = ''
            self.NAT_BC_CRED = ''
            self.VL_BC_COFINS = ''
            self.ALIQ_COFINS = ''
            self.VL_COFINS = ''
            self.COD_CTA = ''            
            self.parametros = {}
            self.fieldnames = ('REG', 'CST_COFINS', 'VL_ITEM', 'NAT_BC_CRED', 'VL_BC_COFINS',
                               'ALIQ_COFINS', 'VL_COFINS', 'COD_CTA')
            self.formato = self.get_formato()

            #todo: terminar de preencher parametros c505

    class registro_C509(TrackedAttributesClass):
        """
            REGISTRO C509: PROCESSO REFERENCIADO
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C509, self).__init__()
            self.REG = 'C509'         #Texto fixo contendo
            self.nivel_h = 3          #nível
            self.pai = 'C500'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.NUM_PROC = ''
            self.IND_PROC = ''
            self.parametros = {}
            self.fieldnames = ('REG', 'NUM_PROC', 'IND_PROC')
            self.formato = self.get_formato()
            #todo: terminar de preencher parametros c505

    class registro_C600(TrackedAttributesClass):
        """
        REGISTRO C600: CONSOLIDAÇÃO DIÁRIA DE NOTAS FISCAIS/CONTAS EMITIDAS DE
        ENERGIA ELÉTRICA (CÓDIGO 06), NOTA FISCAL/CONTA DE FORNECIMENTO D'ÁGUA
        CANALIZADA (CÓDIGO 29) E NOTA FISCAL/CONTA DE FORNECIMENTO DE GÁS
        (CÓDIGO 28) (EMPRESAS OBRIGADAS OU NÃO OBRIGADAS AO CONVENIO ICMS 115/03) –
        DOCUMENTOS DE SAÍDA
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C600, self).__init__()
            self.REG = 'C600'         #Texto fixo contendo
            self.nivel_h = 2          #nível
            self.pai = 'C001'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.COD_MOD = ''         #Código do modelo do documento fiscal, apresentar conforme a Tabela 4.1.1
            self.COD_MUN = ''         #Código do município dos pontos de consumo,conforme a tabela IBGE
            self.SER = ''             #Série do documento fiscal
            self.SUB = ''             #Subsérie do documento fiscal
            self.COD_CONS = ''        #Código de classe de consumo de energia elétrica ou gás: 01 - Comercial 02 - Consumo Próprio 03 - Iluminação Pública 04 - Industrial 05 - Poder Público 06 - Residencial 07 - Rural 08 -Serviço Público.  Código de classe de consumo de Fornecimento de ́água – Tabela 4.4.2.
            self.QTD_CONS = ''        #Quantidade de documentos consolidados neste registro
            self.QTD_CANC = ''        #Quantidade de documentos cancelados
            self.DT_DOC = ''          #Data dos documentos consolidados
            self.VL_DOC = ''          #Valor total dos documentos
            self.VL_DESC = ''         #Valor acumulado dos descontos
            self.CONS = ''            #Consumo total acumulado, em kWh (Código 06)
            self.VL_FORN = ''         #Valor acumulado do fornecimento
            self.VL_SERV_NT = ''      #Valor acumulado dos serviços não-tributados pelo ICMS
            self.VL_TERC = ''         #Valores cobrados em nome de terceiros
            self.VL_DA = ''           #Valor acumulado das despesas acessórias
            self.VL_BC_ICMS = ''      #Valor acumulado da base de cálculo do ICMS
            self.VL_ICMS = ''         #Valor acumulado do ICMS
            self.VL_BC_ICMS_ST = ''   #Valor acumulado da base de cálculo do ICMS substituição tributária
            self.VL_ICMS_ST = ''      #Valor acumulado do ICMS retido por substituição tributária
            self.VL_PIS = ''          #Valor acumulado do PIS
            self.VL_COFINS = ''       #Valor acumulado COFINS
            self.parametros = {}
            self.fieldnames = ()
            self.formato = self.get_formato()
            #todo: terminar de preencher parametros c600

    class registro_C601(TrackedAttributesClass):
        """
        REGISTRO C601: COMPLEMENTO DA CONSOLIDAÇÃO DIÁRIA (CÓDIGOS 06, 28 e
        29) – DOCUMENTOS DE SAÍDAS - PIS/PASEP
        Registro de detalhamento das informações referentes ao PIS/Pasep, consolidadas no registro C600.
        No caso da pessoa jurídica auferir receitas com regimes tributários (CST-PIS) distintos, deve a pessoa jurídica gerar um
        registro para cada CST, conforme a natureza da receita (tributada, não-tributada, de exportação).
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C601, self).__init__()
            self.REG = 'C601'         #Texto fixo contendo
            self.nivel_h = 3          #nível
            self.pai = 'C600'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.NUM_DOC_CANC = ''    #Número do documento fiscal cancelado
            self.CST_PIS = ''
            self.VL_ITEM = ''
            self.VL_BC_PIS = ''
            self.ALIQ_PIS = ''
            self.VL_PIS = ''
            self.COD_CTA = ''
            self.parametros = {}
            self.fieldnames = ()
            self.formato = self.get_formato()
            #todo:terminar de preencher os parametros c601

    class registro_C605(TrackedAttributesClass):
        """
            REGISTRO C605: COMPLEMENTO DA CONSOLIDAÇÃO DIÁRIA (CÓDIGOS 06, 28 e
            29) – DOCUMENTOS DE SAÍDAS – COFINS
            Registro de detalhamento das informações referentes a COFINS, consolidadas no registro C600.
            No caso da pessoa jurídica auferir receitas com regimes tributários (CST-COFINS) distintos, deve a pessoa jurídica gerar
            um registro para cada CST, conforme a natureza da receita (tributada, não-tributada, de exportação).
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C605, self).__init__()
            self.REG = 'C605'         #Texto fixo contendo
            self.nivel_h = 3          #nível
            self.pai = 'C600'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.CST_COFINS = ''
            self.VL_ITEM = ''
            self.VL_BC_COFINS = ''
            self.ALIQ_COFINS = ''
            self.VL_COFINS = ''
            self.COD_CTA = ''
            self.parametros = {}
            self.fieldnames = ()
            self.formato = self.get_formato()
            #todo:terminar de preencher os parametros c605

    class registro_C609(TrackedAttributesClass):
        """
            REGISTRO C609: PROCESSO REFERENCIADO
             """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C609, self).__init__()
            self.REG = 'C609'         #Texto fixo contendo
            self.nivel_h = 4          #nível
            self.pai = 'C600'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.NUM_PROC = ''
            self.IND_PROC = ''
            self.parametros = {}
            self.fieldnames = ()
            self.formato = self.get_formato()
            #todo:terminar de preencher os parametros c609

    class registro_C800(TrackedAttributesClass):
        """
        REGISTRO C800: CUPOM FISCAL ELETRÔNICO (CÓDIGO 59)
        """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C800, self).__init__()
            self.REG = 'C800'         #Texto fixo contendo
            self.nivel_h = 2          #nível
            self.pai = 'C001'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.COD_MOD = ''         #Código do modelo do documento fiscal, conforme a Tabela 4.1.1
            self.COD_SIT = ''         #Código da situação do documento fiscal, conforme a  Tabela 4.1.2
            self.NUM_CFE = ''         #Número do Cupom Fiscal Eletrônico
            self.DT_DOC = ''          #Data da emissão do Cupom Fiscal Eletrônico
            self.VL_CFE = ''          #Valor total do Cupom Fiscal Eletrônico
            self.VL_PIS = ''          #Valor total do PIS
            self.VL_COFINS = ''       #Valor total da COFINS
            self.CNPJ_CPF = ''        #CNPJ ou CPF do destinatário
            self.NR_SAT = ''          #Número de Série do equipamento SAT
            self.CHV_CFE = ''         #Chave do Cupom Fiscal Eletrônico
            self.VL_DESC = ''         #Valor total de descontos
            self.VL_MERC = ''         #Valor total das mercadorias e serviços
            self.VL_OUT_DA = ''       #Valor total de outras despesas acessórias e acréscimos
            self.VL_ICMS = ''         #Valor do ICMS
            self.VL_PIS_ST = ''       #Valor total do PIS retido por subst. trib.
            self.VL_COFINS_ST = ''    #Valor total da COFINS retido por subst. trib.
            self.parametros = {}
            self.fieldnames = ()
            self.formato = self.get_formato()
            #todo:terminar de preencher os parametros c800

    class registro_C810(TrackedAttributesClass):
        """
            REGISTRO C810: DETALHAMENTO DO CUPOM FISCAL ELETRÔNICO (CÓDIGO 59)
            – PIS/PASEP E COFINS
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C810, self).__init__()
            self.REG = 'C810'         #Texto fixo contendo
            self.nivel_h = 3          #nível
            self.pai = 'C800'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.CFOP = ''
            self.VL_ITEM = ''
            self.COD_ITEM = ''
            self.CST_PIS = ''
            self.VL_BC_PIS = ''
            self.ALIQ_PIS = ''
            self.VL_PIS = ''
            self.CST_COFINS = ''
            self.VL_BC_COFINS = ''
            self.ALIQ_COFINS = ''
            self.VL_COFINS = ''
            self.COD_CTA = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'CFOP': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'VL_ITEM': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'COD_ITEM': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'CST_PIS': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'VL_BC_PIS': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'ALIQ_PIS': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'VL_PIS': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'CST_COFINS': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'VL_BC_COFINS': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'ALIQ_COFINS': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'VL_COFINS': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'COD_CTA': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
            }
            self.fieldnames = ()
            self.formato = self.get_formato()
            #todo:verificar o atributo parametros no registro c810

    class registro_C860(TrackedAttributesClass):
        """
        REGISTRO C860: IDENTIFICAÇÃO DO EQUIPAMENTO SAT-CF-E
        Este registro tem por objetivo identificar os equipamentos SAT-CF-e e deve ser informado por todos os
        contribuintes que utilizem tais equipamentos na emissão de documentos fiscais.
        Não poderão ser informados dois ou mais registros com a mesma combinação COD_MOD, NR_SAT, DOC_INI e
        DOC_FIM.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C860, self).__init__()
            self.REG = 'C860'         #Texto fixo contendo
            self.nivel_h = 2          #nível
            self.pai = 'C001'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.COD_MOD = ''         #Código do modelo do documento fiscal, conforme a Tabela  4.1.1
            self.NR_SAT = ''          #Número de Série do equipamento SAT
            self.DT_DOC = ''          #Data de emissão dos documentos fiscais
            self.DOC_INI = ''         #Número do documento inicial
            self.DOC_FIM = ''         #Número do documento final
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_MOD': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'NR_SAT': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'DT_DOC': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'DOC_INI': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'DOC_FIM': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
            }
            self.fieldnames = ()
            self.formato = self.get_formato()
            #todo:verificar o atributo parametros no registro c860

    class registro_C870(TrackedAttributesClass):
        """
        REGISTRO C870: RESUMO DIÁRIO DE DOCUMENTOS
        EQUIPAMENTO SAT-CF-E (CÓDIGO 59) – PIS/PASEP E COFINS
        EMITIDOS
        Registro para demonstração da receita consolidada e apuração das contribuições sociais, por equipamento SAT-CF-e,
        referente aos documentos fiscais emitidos no período.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C870, self).__init__()
            self.REG = 'C870'         #Texto fixo contendo
            self.nivel_h = 2          #nível
            self.pai = 'C001'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.CFOP = ''
            self.VL_ITEM = ''
            self.COD_ITEM = ''
            self.CST_PIS = ''
            self.VL_BC_PIS = ''
            self.ALIQ_PIS = ''
            self.VL_PIS = ''
            self.CST_COFINS = ''
            self.VL_BC_COFINS = ''
            self.ALIQ_COFINS = ''
            self.VL_COFINS = ''
            self.COD_CTA = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'CFOP': {'tipo': 'N', 'tamanho': 4, 'fixa_tamanho': True},
                'VL_ITEM': {'tipo': 'N', 'tamanho': 0, 'decimal': 2, 'fixa_tamanho': False},
                'COD_ITEM': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'CST_PIS': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'VL_BC_PIS': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'ALIQ_PIS': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'VL_PIS': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'CST_COFINS': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'VL_BC_COFINS': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'ALIQ_COFINS': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'VL_COFINS': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'COD_CTA': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
            }
            self.fieldnames = ()
            self.formato = self.get_formato()
            #todo:verificar o atributo parametros no registro c870

    class registro_C880(TrackedAttributesClass):
        """            REGISTRO C880: RESUMO DIÁRIO DE DOCUMENTOS EMITIDOS POR
            EQUIPAMENTO SAT-CF-E (CÓDIGO 59) – PIS/PASEP E COFINS APURADO POR
            UNIDADE DE MEDIDA DE PRODUTO
            """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C880, self).__init__()
            self.REG = 'C880'         #Texto fixo contendo
            self.nivel_h = 2          #nível
            self.pai = 'C001'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.COD_ITEM = ''
            self.CFOP = ''
            self.VL_ITEM = ''
            self.CST_PIS = ''
            self.QUANT_BC_PIS = ''
            self.ALIQ_PIS_QUANT = ''
            self.VL_PIS = ''
            self.CST_COFINS = ''
            self.QUANT_BC_COFINS = ''
            self.ALIQ_COFINS_QUANT = ''
            self.VL_COFINS = ''
            self.COD_CTA = ''
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'COD_ITEM': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'CFOP': {'tipo': 'N', 'tamanho': 4, 'fixa_tamanho': True},
                'VL_ITEM': {'tipo': 'N', 'tamanho': 0, 'decimal': 2, 'fixa_tamanho': False},
                'CST_PIS': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'VL_BC_PIS': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'ALIQ_PIS': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'VL_PIS': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'CST_COFINS': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'VL_BC_COFINS': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'ALIQ_COFINS': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'VL_COFINS': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'COD_CTA': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
            }
            self.fieldnames = ()
            self.formato = self.get_formato()
            #todo:verificar o atributo parametros no registro c880

    class registro_C890(TrackedAttributesClass):
        """
                REGISTRO C890: PROCESSO REFERENCIADO
             """

        _order = []

        def __init__(self):
            super(bloco_c.registro_C890, self).__init__()
            self.REG = 'C890'         #Texto fixo contendo
            self.nivel_h = 3          #nível
            self.pai = 'C001'
            self.ocorrencia = 'N'     #ocorrência por arquivo
            self.NUM_PROC = ''        #Código da Situação Tributária, conforme a Tabela indicada no item 4.3.1
            self.IND_PROC = ''            #Código Fiscal de Operação e Prestação do agrupamento de itens
            self.parametros = {
                'REG': {'tipo': 'C', 'tamanho': 4, 'fixa_tamanho': True},
                'NUM_PROC': {'tipo': 'C', 'tamanho': 20, 'fixa_tamanho': False},
                'IND_PROC': {'tipo': 'N', 'tamanho': 4, 'fixa_tamanho': True},}
            self.fieldnames = ()
            self.formato = self.get_formato()
                #todo:verificar o atributo parametros no registro c890

    class registro_C990(TrackedAttributesClass):
        """
        REGISTRO C990: ENCERRAMENTO DO BLOCO C
        Este registro destina-se a identificar o encerramento do bloco C e informar a quantidade de linhas (registros)
        existentes no bloco.
        """
        _order = []

        def __init__(self):
            super(bloco_c.registro_C990, self).__init__()
            self.REG = 'C990'         #Texto fixo contendo
            self.nivel_h = 1          #nível
            self.pai = '0000'
            self.ocorrencia = '1'     #ocorrência por arquivo
            self.QTD_LIN_C = ''
            self.fieldnames = ('REG', 'QTD_LIN_C')
            self.formato = self.get_formato()



