# -*- coding: utf-8 -*-

from ..utils import *


class bloco_0(TrackedAttributesClass):
    """Classe do Bloco 0"""

    class registro_0001(TrackedAttributesClass):
        """
        REGISTRO 0001: ABERTURA DO BLOCO 0
        Este registro deve ser gerado para abertura do Bloco 0 e indica se há informações previstas para este bloco.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0001, self).__init__()
            self.REG = '0001'  # Texto fixo contendo.
            self.nivel_h = 1  # nível
            self.pai = '0000'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.IND_MOV = '0'  # Indicador de movimento:0- Bloco com dados informados;1- Bloco sem dados informados.
            self.registro_0005 = []
            self.registro_0015 = []
            self.registro_0100 = []
            self.registro_0150 = []
            self.registro_0190 = []
            self.registro_0200 = []
            self.registro_0300 = []
            self.registro_0305 = []
            self.registro_0400 = []
            self.registro_0450 = []
            self.registro_0460 = []
            self.registro_0500 = []
            self.registro_0600 = []
            self.fieldnames = ('REG', 'IND_MOV')
            self.formato = self.get_formato()

    class registro_0005(TrackedAttributesClass):
        """
        REGISTRO 0005: DADOS COMPLEMENTARES DA ENTIDADE
        Registro obrigatório utilizado para complementar as informações de identificação do informante do arquivo.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0005, self).__init__()
            self.REG = '0005'
            self.nivel_h = 1  # nível
            self.pai = '0001'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.FANTASIA = ''  # Nome de fantasia associado
            self.CEP = ''  # Código de Endereçamento Postal #somente o CEP é N
            self.END = ''  # Logradouro e endereço do imóvel
            self.NUM = ''  # Número do imóvel
            self.COMPL = ''  # Dados complementares do endereço
            self.BAIRRO = ''  # Bairro em que o imóvel está situado
            self.FONE = ''  # Número do telefone
            self.FAX = ''  # Número do fax
            self.EMAIL = ''  # Endereço do correio eletrônico
            self.fieldnames = ('REG', 'FANTASIA', 'CEP', 'END', 'NUM', 'COMPL', 'BAIRRO', 'FONE',
                               'FAX', 'EMAIL')
            self.formato = self.get_formato()

    class registro_0015(TrackedAttributesClass):
        """
        REGISTRO 0015: DADOS DO CONTRIBUINTE SUBSTITUTO
        Registro obrigatório para todos os contribuintes substitutos tributários do ICMS, conforme definidos na legislação
        pertinente. Deve ser gerado um registro para cada uma das inscrições estaduais cadastradas nas unidades federadas dos
        contribuintes substituídos, ainda que não tenha tido movimentação no período, ficando obrigado à apresentação dos
        registros E200 e filhos.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0015, self).__init__()
            self.REG = '0015'
            self.nivel_h = 2  # nível
            self.pai = '0001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.UF_ST = ''  # Sigla da unidade da federação do contribuinte substituído.
            self.IE_ST = ''  # Inscrição Estadual do contribuinte substituto na unidade da federação do contribuinte substituído
            self.fieldnames = ('REG', 'UF_ST', 'IE_ST')
            self.formato = self.get_formato()

    class registro_0100(TrackedAttributesClass):
        """
        REGISTRO 0100: DADOS DO CONTABILISTA
        Registro utilizado para identificação do contabilista responsável pela escrituração fiscal do estabelecimento,
        mesmo que o contabilista seja funcionário da empresa ou prestador de serviço.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0100, self).__init__()
            self.REG = '0100'
            self.nivel_h = 2
            self.pai = '0001'
            self.ocorrencia = '1'
            self.NOME = ''  # Nome do contabilista
            self.CPF = ''  # Número de inscrição do contabilista no CPF.
            self.CRC = ''  # Número de inscrição do contabilista no Conselho Regional de Contabilidade.
            self.CNPJ = ''  # Número de inscrição do escritório de contabilidade no CNPJ, se houver.
            self.CEP = ''  # Código de Endereçamento Postal.
            self.END = ''  # Logradouro e endereço do imóvel.
            self.NUM = ''  # Número do imóvel
            self.COMPL = ''  # Dados complementares do endereço.
            self.BAIRRO = ''  # Bairro em que o imóvel está situado.
            self.FONE = ''  # Número do telefone (DDD+FONE).
            self.FAX = ''  # Número do fax.
            self.EMAIL = ''  # Endereço do correio eletrônico.
            self.COD_MUN = ''  # Código do município, conforme tabela IBGE.
            self.fieldnames = ('REG', 'NOME', 'CPF', 'CRC', 'CNPJ', 'CEP', 'END', 'NUM', 'COMPL',
                               'BAIRRO', 'FONE', 'FAX', 'EMAIL', 'COD_MUN')
            self.formato = self.get_formato()

    class registro_0150(TrackedAttributesClass):
        """
        REGISTRO 0150: TABELA DE CADASTRO DO PARTICIPANTE
        Registro utilizado para informações cadastrais das pessoas físicas ou jurídicas envolvidas nas transações
        comerciais com o estabelecimento, no período. Participantes sem movimentação no período não devem ser informados
        neste registro.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0150, self).__init__()
            self.REG = '0150'
            self.nivel_h = 2
            self.pai = '0001'
            self.ocorrencia = 'N'
            self.COD_PART = ''  # Código de identificação do participante no arquivo.
            self.NOME = ''  # Nome pessoal ou empresarial do participante.
            self.COD_PAIS = ''  # Código do país do participante, conforme a tabela indicada no item 3.2.1
            self.CNPJ = ''  # CNPJ do participante.
            self.CPF = ''  # CPF do participante.
            self.IE = ''  # Inscrição Estadual do participante.
            self.COD_MUN = ''  # Código do município, conforme a tabela IBGE
            self.SUFRAMA = ''  # Número de inscrição do participante na SUFRAMA.
            self.END = ''  # Logradouro e endereço do imóvel
            self.NUM = ''  # Número do imóvel
            self.COMPL = ''  # Dados complementares do endereço
            self.BAIRRO = ''  # Bairro em que o imóvel está situado
            self.registro_0175 = []
            self.fieldnames = ('REG', 'COD_PART', 'NOME', 'COD_PAIS', 'CNPJ', 'CPF', 'IE',
                               'COD_MUN', 'SUFRAMA', 'END', 'NUM', 'COMPL', 'BAIRRO')
            self.formato = self.get_formato()

    class registro_0175(TrackedAttributesClass):
        """
        REGISTRO 0175: Alteração da Tabela de Cadastro de Participante
        Este registro é de preenchimento obrigatório quando houver, dentro do período, alteração nos dados informados no
        registro 0150, campos: NOME, COD_PAIS, CNPJ, CPF, IE, COD_MUN, SUFRAMA, END, NUM, COMPL e BAIRRO.
        Não pode ser utilizado, em um mesmo arquivo, um mesmo código para representar um participante diferente do
        referenciado anteriormente por tal código.
        Os dados informados neste registro serão considerados até às 24:00 horas do dia anterior à data de alteração.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0175, self).__init__()
            self.REG = '0175'
            self.nivel_h = 3
            self.pai = '0150'
            self.ocorrencia = 'N'
            self.DT_ALT = ''  # Data de alteração do cadastro
            self.NR_CAMPO = ''  # Número do campo alterado (Somente campos 03 a 13)
            self.CONT_ANT = ''  # Conteúdo anterior do campo
            self.fieldnames = ('REG', 'DT_ALT', 'NR_CAMPO', 'CONT_ANT')
            self.formato = self.get_formato()

    class registro_0190(TrackedAttributesClass):
        """
        REGISTRO 0190: IDENTIFICAÇÃO DAS UNIDADES DE MEDIDA
        Este registro tem por objetivo descrever as unidades de medidas utilizadas no arquivo digital. Não podem ser
        informados dois ou mais registros com o mesmo código de unidade de medida. Somente devem constar as unidades de
        medidas informadas nos demais blocos.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0190, self).__init__()
            self.REG = '0190'
            self.nivel_h = 2
            self.pai = '0001'
            self.ocorrencia = 'N'
            self.UNID = ''  # Código da unidade de medida
            self.DESCR = ''  # Descrição da unidade de medida
            self.fieldnames = ('REG', 'UNID', 'DESCR')
            self.formato = self.get_formato()

    class registro_0200(TrackedAttributesClass):
        """
        REGISTRO 0200: TABELA DE IDENTIFICAÇÃO DO ITEM (PRODUTO E SERVIÇOS)
        Este registro tem por objetivo informar mercadorias, serviços, produtos ou quaisquer outros itens concernentes às
        transações fiscais. Quando ocorrer alteração somente na descrição do item, sem que haja descaracterização deste, ou seja,
        criação de um novo item, a alteração deve constar no registro 0205.
        Só devem ser apresentados itens referenciados nos demais blocos.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0200, self).__init__()
            self.REG = '0200'
            self.nivel_h = 2
            self.pai = '0001'
            self.ocorrencia = 'N'
            self.COD_ITEM = ''  # Código do item
            self.DESCR_ITEM = ''  # Descrição do item
            self.COD_BARRA = ''  # Representação alfanumérico do código de barra do produto, se houver
            self.COD_ANT_ITEM = ''  # Código anterior do item com relação à última informação apresentada.
            self.UNID_INV = ''  # Unidade de medida utilizada na quantificação de estoques.
            self.TIPO_ITEM = ''  # Tipo do item – Atividades Industriais, Comerciais e Serviços:
            self.COD_NCM = ''  # Código da Nomenclatura Comum do Mercosul
            self.EX_IPI = ''  # Código EX, conforme a TIPI
            self.COD_GEN = ''  # Código do gênero do item, conforme a Tabela 4.2.1
            self.COD_LST = ''  # Código do serviço conforme lista do Anexo I da Lei Complementar Federal no 116/03.
            self.ALIQ_ICMS = ''  # Alíquota de ICMS aplicável ao item nas operações internas.
            self.registro_0205 = []
            self.registro_0206 = []
            self.registro_0220 = []
            self.fieldnames = ('REG', 'COD_ITEM', 'DESCR_ITEM', 'COD_BARRA', 'COD_ANT_ITEM',
                               'UNID_INV', 'TIPO_ITEM', 'COD_NCM', 'EX_IPI', 'COD_GEN', 'COD_LST',
                               'ALIQ_ICMS')
            self.formato = self.get_formato()

    class registro_0205(TrackedAttributesClass):
        """
        REGISTRO 0205: ALTERAÇÃO DO ITEM
        Este registro tem por objetivo informar alterações ocorridas na descrição do produto, desde que não o
        descaracterize ou haja modificação que o identifique como sendo novo produto, caso não tenha ocorrido movimentação no
        período da alteração do item, deverá ser informada no primeiro período em que houver movimentação do item.
        Deverá ser ainda informado quando ocorrer alteração na codificação do produto.
        Não podem ser informados dois ou mais registros com sobreposição de períodos.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0205, self).__init__()
            self.REG = '0205'
            self.nivel_h = 3
            self.pai = '0200'
            self.ocorrencia = 'N'
            self.DESCR_ANT_ITEM = ''  # Descrição anterior do item
            self.DT_INI = ''  # Data inicial de utilização da descrição do item
            self.DT_FIM = ''  # Data final de utilização da descrição do item
            self.COD_ANT_ITEM = ''  # Código anterior do item com relação à última informação apresentada.
            self.fieldnames = ('REG', 'DESCR_ANT_ITEM', 'DT_INI', 'DT_FIM', 'COD_ANT_ITEM')
            self.formato = self.get_formato()

    class registro_0206(TrackedAttributesClass):
        """
        REGISTRO 0206: CÓDIGO DE PRODUTO CONFORME TABELA PUBLICADA PELA ANP (COMBUSTÍVEIS)
        Este registro tem por objetivo informar o código correspondente ao produto constante na Tabela da Agência
        Nacional de Petróleo (ANP) para os produtos denominados “Combustíveis”.
        Deve ser apresentado apenas pelos contribuintes produtores, importadores e distribuidores de combustíveis.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0206, self).__init__()
            self.REG = '0206'
            self.nivel_h = 3
            self.pai = '0200'
            self.ocorrencia = '1'
            self.COD_COMB = ''  # Código do combustível, conforme tabela publicada pela ANP
            self.fieldnames = ('REG', 'COD_COMB')
            self.formato = self.get_formato()

    class registro_0220(TrackedAttributesClass):
        """
        REGISTRO 0220: FATORES DE CONVERSÃO DE UNIDADES
        Este registro tem por objetivo informar os fatores de conversão dos itens discriminados na Tabela de Identificação
        do Item (Produtos e Serviços) entre a unidade informada no registro 0200 e as unidades informadas nos registros dos
        documentos fiscais.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0220, self).__init__()
            self.REG = '0220'
            self.nivel_h = 3
            self.pai = '0200'
            self.ocorrencia = 'N'
            self.UNID_CONV = ''  # Unidade comercial a ser convertida na unidade de estoque, referida no registro 0200.
            self.FAT_CONV = ''  # Fator de conversão: fator utilizado para converter (multiplicar) a unidade a ser convertida na unidade adotada no inventário.
            self.fieldnames = ('REG', 'UNID_CONV', 'FAT_CONV')
            self.formato = self.get_formato()

    class registro_0300(TrackedAttributesClass):
        """
        REGISTRO 0300: CADASTRO DE BENS OU COMPONENTES DO ATIVO IMOBILIZADO
        Este registro tem o objetivo de identificar e caracterizar todos os bens ou componentes arrolados no registro G125
        do Bloco G e os bens em construção.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0300, self).__init__()
            self.REG = '0300'
            self.nivel_h = 2
            self.pai = '0001'
            self.ocorrencia = 'N'
            self.COD_IND_BEM = ''  # Código individualizado do bem ou componente adotado no controle patrimonial do estabelecimento informante
            self.IDENT_MERC = ''  # Identificação do tipo de mercadoria:  1 = bem; 2 = componente.
            self.DESCR_ITEM = ''  # Descrição do bem ou componente (modelo, marca e outras características necessárias a sua individualização)
            self.COD_PRNC = ''  # Código de cadastro do bem principal nos casos em que o bem ou componente ( campo 02) esteja vinculado a um bem principal.
            self.COD_CTA = ''  # Código da conta analítica de contabilização do bem ou componente (campo 06 do Registro 0500).
            self.NR_PARC = ''  # Número total de parcelas a serem apropriadas, segundo a legislação de cada unidade federada.
            self.fieldnames = ('REG', 'COD_IND_BEM', 'IDENT_MERC', 'DESCR_ITEM', 'COD_PRNC',
                               'COD_CTA', 'NR_PARC')
            self.formato = self.get_formato()

    class registro_0305(TrackedAttributesClass):
        """
        REGISTRO 0305 – INFORMAÇÃO SOBRE A UTILIZAÇÃO DO BEM
        Este registro tem o objetivo de prestar informações sobre a utilização do bem, sendo obrigatório quando o
        conteúdo do campo IDENT_MERC do registro 0300 for igual a “1”.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0305, self).__init__()
            self.REG = '0305'
            self.nivel_h = 3
            self.pai = '0300'
            self.ocorrencia = '1'
            self.COD_CCUS = ''  # Código do centro de custo onde o bem está sendo ou será utilizado (campo 03 do Registro 0600)
            self.FUNC = ''  # Descrição sucinta da função do bem na atividade do estabelecimento
            self.VIDA_UTIL = ''  # Vida útil estimada do bem, em número de meses
            self.fieldnames = ('REG', 'COD_CCUS', 'FUNC', 'VIDA_UTIL')
            self.formato = self.get_formato()

    class registro_0400(TrackedAttributesClass):
        """
        REGISTRO 0400: TABELA DE NATUREZA DA OPERAÇÃO/PRESTAÇÃO
        Este registro tem por objetivo codificar os textos das diferentes naturezas da operação/prestação discriminadas nos
        documentos fiscais. Esta codificação e suas descrições são livremente criadas e mantidas pelo contribuinte.
        Este registro não se refere a CFOP. Algumas empresas utilizam outra classificação além das apresentados nos
        CFOP. Esta codificação permite informar estes agrupamentos próprios.
        Não podem ser informados dois ou mais registros com o mesmo conteúdo no campo COD_NAT
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0400, self).__init__()
            self.REG = '0400'
            self.nivel_h = 2
            self.pai = '0001'
            self.ocorrencia = 'N'
            self.COD_NAT = ''  # Código da natureza da operação/prestação
            self.DESCR_NAT = ''  # Descrição da natureza da operação/prestação
            self.fieldnames = ('REG', 'COD_NAT', 'DESCR_NAT')
            self.formato = self.get_formato()

    class registro_0450(TrackedAttributesClass):
        """
        REGISTRO 0450: TABELA DOCUMENTO FISCAL DE INFORMAÇÃO COMPLEMENTAR DO DOCUMENTO FISCAL
        Este registro tem por objetivo codificar todas as informações complementares dos documentos fiscais, exigidas
        pela legislação fiscal. Estas informações constam no campo “Dados Adicionais” dos documentos fiscais.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0450, self).__init__()
            self.REG = '0450'
            self.nivel_h = 2
            self.pai = '0001'
            self.ocorrencia = 'N'
            self.COD_INF = ''  # Código da informação complementar do documento fiscal
            self.TXT = ''  # Texto livre da informação complementar existente no documento fiscal, inclusive espécie de normas legais, poder normativo, número, capitulação, data e demais referências pertinentes com indicação referentes ao tributo.
            self.fieldnames = ('REG', 'COD_INF', 'TXT')
            self.formato = self.get_formato()

    class registro_0460(TrackedAttributesClass):
        """
        REGISTRO 0460: TABELA DE OBSERVAÇÕES DO LANÇAMENTO FISCAL
        Este registro é utilizado para informar anotações de escrituração determinadas pela legislação pertinente aos
        lançamentos fiscais, tais como: ajustes efetuados por diferimento parcial de imposto, antecipações, diferencial de alíquota e
        outros.Esta codificação e suas descrições são de atribuição do contribuinte e não podem ser informados dois ou mais registros com o mesmo conteúdo no campo COD_OBS.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0460, self).__init__()
            self.REG = '0460'
            self.nivel_h = 2
            self.pai = '0001'
            self.ocorrencia = 'N'
            self.COD_OBS = ''  # Código da Observação do lançamento fiscal.
            self.TXT = ''  # Descrição da observação vinculada ao lançamento fiscal.
            self.fieldnames = ('REG', 'COD_OBS', 'TXT')
            self.formato = self.get_formato()

    class registro_0500(TrackedAttributesClass):
        """
        REGISTRO 0500: PLANO DE CONTAS CONTÁBEIS
        Este registro tem o objetivo de identificar as contas contábeis utilizadas pelo contribuinte informante em sua
        Contabilidade Geral, no que se refere às contas referenciadas no registro 0300. Não podem ser informados dois ou mais
        registros com a mesma combinação de conteúdo nos campos DT_ALT e COD_CTA.
        """

        _order = []

        def __init__(self):
            super(bloco_0.registro_0500, self).__init__()
            self.REG = '0500'
            self.nivel_h = 2
            self.pai = '0001'
            self.ocorrencia = 'N'
            self.DT_ALT = ''  # Data da inclusão/alteração
            self.COD_NAT_CC = ''  # Código da natureza da conta/grupo de contas:01 - Contas de ativo; 02 - Contas de passivo;03 - Patrimônio líquido; 04 - Contas de resultado;05 - Contas de compensação;09 - Outras.
            self.IND_CTA = ''  # Indicador do tipo de conta: S - Sintética (grupo de contas); A - Analítica (conta).
            self.NIVEL = ''  # Nível da conta analítica/grupo de contas.
            self.COD_CTA = ''  # Código da conta analítica/grupo de contas.
            self.NOME_CTA = ''  # Nome da conta analítica/grupo de contas.
            self.fieldnames = ('REG', 'DT_ALT', 'COD_NAT_CC', 'IND_CTA', 'NIVEL', 'COD_CTA',
                               'NOME_CTA')
            self.formato = self.get_formato()

    class registro_0600(TrackedAttributesClass):
        """
        REGISTRO 0600: CENTRO DE CUSTOS
        Este registro tem o objetivo de identificar os centros de custos referenciados no registro 0305.
        Não podem ser informados dois ou mais registros com a mesma combinação de conteúdo nos campos DT_ALT e
        COD_CCUS.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0600, self).__init__()
            self.REG = '0600'
            self.nivel_h = 2
            self.pai = '0001'
            self.ocorrencia = 'N'
            self.DT_ALT = ''  # Data da inclusão/alteração.
            self.COD_CCUS = ''  # Código do centro de custos.
            self.CCUS = ''  # Nome do centro de custos.
            self.fieldnames = ('REG', 'DT_ALT', 'COD_CCUS', 'CCUS')
            self.formato = self.get_formato()

    class registro_0990(TrackedAttributesClass):
        """
        REGISTRO 0990: ENCERRAMENTO DO BLOCO 0
        Este registro tem por objetivo identificar o encerramento do bloco 0 e informar a quantidade de linhas (registros)
        existentes no bloco.
        """
        _order = []

        def __init__(self):
            super(bloco_0.registro_0990, self).__init__()
            self.REG = '0990'
            self.nivel_h = 1
            self.pai = '0000'
            self.ocorrencia = '1'
            self.QTD_LIN_0 = ''  # Quantidade total de linhas do Bloco 0
            self.fieldnames = ('REG', 'QTD_LIN_0')
            self.formato = self.get_formato()
