# -*- coding: utf-8 -*-

from ..utils import *


class bloco_e(TrackedAttributesClass):
    """
    BLOCO E: APURAÇÃO DO ICMS E DO IPI
    Bloco de registros dos dados relativos à apuração do ICMS e do IPI.
    """


    class registro_E001(TrackedAttributesClass):
        """
        REGISTRO E001: ABERTURA DO BLOCO E
        Este registro tem por objetivo abrir o Bloco E e indica se há informações sobre apuração do ICMS e do IPI.
        """
        _order = []

        def __init__(self):
            super(bloco_e.registro_E001, self).__init__()
            self.REG = 'E001'  # Texto fixo contendo
            self.nivel_h = 1  # nível
            self.pai = '0000'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.IND_MOV = ''
            self.fieldnames = ('REG', 'IND_MOV')
            self.formato = self.get_formato()

    class registro_E100(TrackedAttributesClass):
        """
        REGISTRO E100: PERÍODO DA APURAÇÃO DO ICMS.
        Este registro tem por objetivo informar o(s) período(s) de apuração do ICMS. Os períodos informados devem
        abranger todo o intervalo da escrituração fiscal, sem sobreposição ou omissão de datas ou períodos.
        """
        _order = []

        def __init__(self):
            super(bloco_e.registro_E100, self).__init__()
            self.REG = 'E100'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = 'E001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.DT_INI = ''
            self.DT_FIN = ''
            self.fieldnames = ('REG', 'DT_INI', 'DT_FIN')
            self.formato = self.get_formato()

    class registro_E110(TrackedAttributesClass):
        """
        REGISTRO E110: APURAÇÃO DO ICMS – OPERAÇÕES PRÓPRIAS.
        Este registro tem por objetivo informar os valores relativos à apuração do ICMS referentes às operações próprias.
        O registro deve ser apresentado inclusive nos casos de períodos sem movimento. Neste caso, os valores deverão ser
        apresentados zerados.
        """
        _order = []

        def __init__(self):
            super(bloco_e.registro_E110, self).__init__()
            self.REG = 'E110'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'E100'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.VL_TOT_DEBITOS = ''
            self.VL_AJ_DEBITOS = ''
            self.VL_TOT_AJ_DEBITOS = ''
            self.VL_ESTORNOS_CRED = ''
            self.VL_TOT_CREDITOS = ''
            self.VL_AJ_CREDITOS = ''
            self.VL_TOT_AJ_CREDITOS = ''
            self.VL_ESTORNOS_DEB = ''
            self.VL_SLD_CREDOR_ANT = ''
            self.VL_SLD_APURADO = ''
            self.VL_TOT_DED = ''
            self.VL_ICMS_RECOLHER = ''
            self.VL_SLD_CREDOR_TRANSPORTAR = ''
            self.DEB_ESP = ''
            self.fieldnames = ('REG', 'VL_TOT_DEBITOS', 'VL_AJ_DEBITOS', 'VL_TOT_AJ_DEBITOS',
                               'VL_ESTORNOS_CRED', 'VL_TOT_CREDITOS', 'VL_AJ_CREDITOS',
                               'VL_TOT_AJ_CREDITOS', 'VL_ESTORNOS_DEB', 'VL_SLD_CREDOR_ANT',
                               'VL_SLD_APURADO', 'VL_TOT_DED', 'VL_ICMS_RECOLHER',
                               'VL_SLD_CREDOR_TRANSPORTAR', 'DEB_ESP')
            self.formato = self.get_formato()


    class registro_E111(TrackedAttributesClass):
        """
        REGISTRO E111: AJUSTE/BENEFÍCIO/INCENTIVO DA APURAÇÃO DO ICMS.
        Este registro tem por objetivo discriminar todos os ajustes lançados nos campos VL_TOT_AJ_DEBITOS,
        VL_ESTORNOS_CRED, VL_TOT_AJ_CREDITOS, VL_ESTORNOS_DEB, VL_TOT_DED e DEB_ESP, todos do
        registro E110.
        """
        _order = []

        def __init__(self):
            super(bloco_e.registro_E111, self).__init__()
            self.REG = 'E111'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'E110'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_AJ_APUR = ''
            self.DESCR_COMPL_AJ = ''
            self.VL_AJ_APUR = ''
            self.fieldnames = ('REG', 'COD_AJ_APUR', 'DESCR_COMPL_AJ', 'VL_AJ_APUR')
            self.formato = self.get_formato()

    class registro_E112(TrackedAttributesClass):
        """
        REGISTRO E112: INFORMAÇÕES ADICIONAIS DOS AJUSTES DA APURAÇÃO DO ICMS.
        Este registro tem por objetivo detalhar os ajustes do registro E111 quando forem relacionados a processos judiciais
        ou fiscais ou a documentos de arrecadação, observada a legislação estadual pertinente. Valores recolhidos, com influência
        na apuração do ICMS – Operações Próprias, devem ser detalhados neste registro, com identificação do documento de
        arrecadação específico.
        """
        _order = []

        def __init__(self):
            super(bloco_e.registro_E112, self).__init__()
            self.REG = 'E112'  # Texto fixo contendo
            self.nivel_h = 5  # nível
            self.pai = 'E111'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_DA = ''
            self.NUM_PROC = ''
            self.IND_PROC = ''
            self.PROC = ''
            self.TXT_COMPL = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_E113(TrackedAttributesClass):
        """
        REGISTRO E113: INFORMAÇÕES ADICIONAIS DOS AJUSTES DA APURAÇÃO DO ICMS – IDENTIFICAÇÃO DOS DOCUMENTOS FISCAIS.
        Este registro tem por objetivo identificar os documentos fiscais relacionados ao ajuste.
        """
        _order = []

        def __init__(self):
            super(bloco_e.registro_E113, self).__init__()
            self.REG = 'E113'  # Texto fixo contendo
            self.nivel_h = 5  # nível
            self.pai = 'E111'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_PART = ''
            self.COD_MOD = ''
            self.SER = ''
            self.SUB = ''
            self.NUM_DOC = ''
            self.DT_DOC = ''
            self.COD_ITEM = ''
            self.VL_AJ_ITEM = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_E115(TrackedAttributesClass):
        """
        REGISTRO E115:DECLARATÓRIOS.INFORMAÇÕES ADICIONAIS DA APURAÇÃO – VALORES
        Este registro tem o objetivo de informar os valores declaratórios relativos ao ICMS, conforme definição da
        legislação estadual pertinente. Esses valores são meramente declaratórios e não são computados na apuração do
        ICMS.
        """
        _order = []

        def __init__(self):
            super(bloco_e.registro_E115, self).__init__()
            self.REG = 'E115'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'E110'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_INF_ADIC = ''
            self.VL_INF_ADIC = ''
            self.DESCR_COMPL_AJ = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_E116(TrackedAttributesClass):
        """
        REGISTRO E116: OBRIGAÇÕES DO ICMS A RECOLHER – OPERAÇÕES PRÓPRIAS.
        Este registro tem o objetivo de discriminar os pagamentos realizados (débitos especiais) ou a realizar, referentes à
        apuração do ICMS – Operações Próprias do período. A soma do valor das obrigações deste registro deve ser igual à soma
        dos campos VL_ICMS_RECOLHER e DEB_ESP, do registro E110.
        """
        _order = []

        def __init__(self):
            super(bloco_e.registro_E116, self).__init__()
            self.REG = 'E116'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'E110'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_OR = ''
            self.VL_OR = ''
            self.DT_VCTO = ''
            self.COD_REC = ''
            self.NUM_PROC = ''
            self.IND_PROC = ''
            self.PROC = ''
            self.TXT_COMPL = ''
            self.MES_REF = ''
            self.fieldnames = ('REG', 'COD_OR', 'VL_OR', 'DT_VCTO', 'COD_REC', 'NUM_PROC',
                               'IND_PROC', 'PROC', 'TXT_COMPL', 'MES_REF')
            self.formato = self.get_formato()

    class registro_E200(TrackedAttributesClass):
        """
        REGISTRO E200: PERÍODO DA APURAÇÃO DO ICMS - SUBSTITUIÇÃO TRIBUTÁRIA.
        Este registro tem por objetivo informar o(s) período(s) de apuração do ICMS – Substituição Tributária para cada
        UF onde o informante seja inscrito como substituto tributário, inclusive para o seu estado, nas operações internas que
        envolvam substituição, e também para UF para a qual o declarante tenha comercializado e que não tenha inscrição como
        substituto. Os períodos informados devem abranger todo o período previsto no registro 0000, sem haver sobreposição ou
        omissão de datas, por UF
        """
        _order = []

        def __init__(self):
            super(bloco_e.registro_E200, self).__init__()
            self.REG = 'E200'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = 'E001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.UF = ''
            self.DT_INI = ''
            self.DT_FIN = ''
            self.fieldnames = ('REG', 'UF', 'DT_INI', 'DT_FIN')
            self.formato = self.get_formato()

    class registro_E210(TrackedAttributesClass):
        """
         REGISTRO E210: APURAÇÃO DO ICMS – SUBSTITUIÇÃO TRIBUTÁRIA.
         Este registro tem por objetivo informar valores relativos à apuração do ICMS de substituição tributária, mesmo
         nos casos de períodos sem movimento.
        """
        _order = []

        def __init__(self):
            super(bloco_e.registro_E210, self).__init__()
            self.REG = 'E210'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'E200'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.IND_MOV_ST = ''
            self.VL_SLD_CRED_ANT_ST = ''
            self.VL_DEVOL_ST = ''
            self.VL_RESSARC_ST = ''
            self.VL_OUT_CRED_ST = ''
            self.VL_AJ_CREDITOS_ST = ''
            self.VL_RETENCAO_ST = ''
            self.VL_OUT_DEB_ST = ''
            self.VL_AJ_DEBITOS_ST = ''
            self.VL_SLD_DEV_ANT_ST = ''
            self.VL_DEDUCOES_ST = ''
            self.VL_ICMS_RECOL_ST = ''
            self.VL_SLD_CRED_ST_TRANSPORTAR = ''
            self.DEB_ESP_ST = ''
            self.fieldnames = ('REG', 'IND_MOV_ST', 'VL_SLD_CRED_ANT_ST', 'VL_DEVOL_ST',
                               'VL_RESSARC_ST', 'VL_OUT_CRED_ST', 'VL_AJ_CREDITOS_ST',
                               'VL_RETENCAO_ST', 'VL_OUT_DEB_ST', 'VL_AJ_DEBITOS_ST',
                               'VL_SLD_DEV_ANT_ST', 'VL_DEDUCOES_ST', 'VL_ICMS_RECOL_ST',
                               'VL_SLD_CRED_ST_TRANSPORTAR', 'DEB_ESP_ST')
            self.formato = self.get_formato()

    class registro_E220(TrackedAttributesClass):
        """
        REGISTRO E220: AJUSTE/BENEFÍCIO/INCENTIVO DA APURAÇÃO DO ICMS
        SUBSTITUIÇÃO TRIBUTÁRIA.
        Este registro deve ser apresentado para discriminar os ajustes lançados nos campos VL_OUT_CRED_ST,
        VL_OUT_DEB_ST e VL_DEDUÇOES_ST e os valores informados no campo DEB_ESP_ST, todos do registro E210.
        """
        _order = []

        def __init__(self):
            super(bloco_e.registro_E220, self).__init__()
            self.REG = 'E220'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'E210'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_AJ_APUR = ''
            self.DESCR_COMPL_AJ = ''
            self.VL_AJ_APUR = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_E230(TrackedAttributesClass):
        """
        REGISTRO E230: INFORMAÇÕES ADICIONAIS DOS AJUSTES DA APURAÇÃO DO
        ICMS SUBSTITUIÇÃO TRIBUTÁRIA.
        Este registro deve ser apresentado para detalhar os ajustes do registro E220 quando forem relacionados a processos
        judiciais ou fiscais ou a documentos de arrecadação, observada a legislação estadual pertinente. Valores recolhidos, com
        influência na apuração do ICMS-ST, devem ser informados neste registro, com identificação do documento de arrecadação
        específico.
        """
        _order = []

        def __init__(self):
            super(bloco_e.registro_E230, self).__init__()
            self.REG = 'E230'  # Texto fixo contendo
            self.nivel_h = 5  # nível
            self.pai = 'E220'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.NUM_DA = ''
            self.NUM_PROC = ''
            self.IND_PROC = ''
            self.PROC = ''
            self.TXT_COMPL = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_E240(TrackedAttributesClass):
        """
        REGISTRO E240: INFORMAÇÕES ADICIONAIS DOS AJUSTES DA APURAÇÃO DO
        ICMS SUBSTITUIÇÃO TRIBUTÁRIA – IDENTIFICAÇÃO DOS DOCUMENTOS FISCAIS.
        Este registro deve ser apresentado para identificação dos documentos fiscais relacionados ao ajuste.
        """
        _order = []

        def __init__(self):
            super(bloco_e.registro_E240, self).__init__()
            self.REG = 'E240'  # Texto fixo contendo
            self.nivel_h = 5  # nível
            self.pai = 'E220'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_PART = ''
            self.COD_MOD = ''
            self.SER = ''
            self.SUB = ''
            self.NUM_DOC = ''
            self.DT_DOC = ''
            self.COD_ITEM = ''
            self.VL_AJ_ITEM = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_E250(TrackedAttributesClass):
        """
        REGISTRO E250:TRIBUTÁRIA. OBRIGAÇÕES DO ICMS A RECOLHER – SUBSTITUIÇÃO
        Este registro deve ser apresentado para discriminar os pagamentos realizados (Débitos especiais) ou a realizar,
        referentes à apuração do ICMS devido por Substituição Tributária do período, por UF. A soma do valor das obrigações a
        serem discriminadas neste registro deve ser igual ao campo VL_ICMS_RECOL_ST (registro E210) somado ao campo
        DEB_ESP_ST (registro E210) e o somatório dos valores informados no registro C197 (cujo terceiro e quarto caractere seja
        igual a “71”).
        """
        _order = []

        def __init__(self):
            super(bloco_e.registro_E250, self).__init__()
            self.REG = 'E250'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'E210'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.COD_OR = ''
            self.VL_OR = ''
            self.DT_VCTO = ''
            self.COD_REC = ''
            self.NUM_PROC = ''
            self.IND_PROC = ''
            self.PROC = ''
            self.TXT_COMPL = ''
            self.MES_REF = ''
            self.fieldnames = ('REG', 'COD_OR', 'VL_OR', 'DT_VCTO', 'COD_REC', 'NUM_PROC',
                               'IND_PROC', 'PROC', 'TXT_COMPL', 'MES_REF')
            self.formato = self.get_formato()

    class registro_E300(TrackedAttributesClass):
        """
        REGISTRO E300: PERÍODO DE APURAÇÃO DO ICMS DIFERENCIAL DE ALÍQUOTA –
        UF ORIGEM/DESTINO EC 87/15
        """
        _order = []

        def __init__(self):
            super(bloco_e.registro_E300, self).__init__()
            self.REG = 'E300'
            self.nivel_h = 2
            self.pai = 'E001'
            self.ocorrencia = 'N'
            self.UF = ''
            self.DT_INI = ''
            self.DT_FIN = ''
            self.fieldnames = ('REG', 'UF', 'DT_INI', 'DT_FIN')
            self.formato = self.get_formato()

    class registro_E310(TrackedAttributesClass):
        """
        Este registro tem por objetivo informar valores relativos à apuração do ICMS – Diferencial
        de Alíquota e Fundo de Combate à Pobreza - FCP, por UF origem/destino, mesmo nos casos de
        períodos sem movimento. Registro obrigatório, se existir o registro E300.
        """
        _order = []

        def __init__(self):
            super(bloco_e.registro_E310, self).__init__()
            self.REG = 'E310'
            self.nivel_h = 3
            self.pai = 'E300'
            self.ocorrencia = '1'
            self.IND_MOV_DIFAL = ''
            self.VL_SLD_CRED_ANT_DIFAL = ''
            self.VL_TOT_DEBITOS_DIFAL = ''
            self.VL_OUT_DEB_DIFAL = ''
            self.VL_TOT_DEB_FCP = ''
            self.VL_TOT_CREDITOS_DIFAL = ''
            self.VL_TOT_CRED_FCP = ''
            self.VL_OUT_CRED_DIFAL = ''
            self.VL_SLD_DEV_ANT_DIFAL = ''
            self.VL_DEDUCOES_DIFAL = ''
            self.VL_RECOL = ''
            self.VL_SLD_CRED_TRANSPORTAR = ''
            self.DEB_ESP_DIFAL = ''
            self.fieldnames = ('REG', 'IND_MOV_DIFAL', 'VL_SLD_CRED_ANT_DIFAL',
                               'VL_TOT_DEBITOS_DIFAL', 'VL_OUT_DEB_DIFAL', 'VL_TOT_DEB_FCP',
                               'VL_TOT_CREDITOS_DIFAL', 'VL_TOT_CRED_FCP', 'VL_OUT_CRED_DIFAL',
                               'VL_SLD_DEV_ANT_DIFAL', 'VL_DEDUCOES_DIFAL', 'VL_RECOL',
                               'VL_SLD_CRED_TRANSPORTAR', 'DEB_ESP_DIFAL')
            self.formato = self.get_formato()

    class registro_E316(TrackedAttributesClass):
        """
        REGISTRO E316: OBRIGAÇÕES DO ICMS RECOLHIDO OU A RECOLHER –
        DIFERENCIAL DE ALÍQUOTA UF ORIGEM/DESTINO EC 87/15.
        """

        def __init__(self):
            super(bloco_e.registro_E316, self).__init__()
            self.REG = 'E316'
            self.nivel_h = 4
            self.pai = 'E310'
            self.ocorrencia = 'N'
            self.COD_OR = ''
            self.VL_OR = ''
            self.DT_VCTO = ''
            self.COD_REC = ''
            self.NUM_PROC = ''
            self.IND_PROC = ''
            self.PROC = ''
            self.TXT_COMPL = ''
            self.MES_REF = ''
            self.fieldnames = ('REG', 'COD_OR', 'VL_OR', 'DT_VCTO', 'COD_REC', 'NUM_PROC',
                               'IND_PROC', 'PROC', 'TXT_COMPL', 'MES_REF')
            self.formato = self.get_formato()

    class registro_E500(TrackedAttributesClass):
        """
        REGISTRO E500: PERÍODO DE APURAÇÃO DO IPI.
        Este registro deve ser apresentado pelos estabelecimentos industriais ou equiparados, conforme dispõe o
        Regulamento do IPI, para identificação do(s) período(s) de apuração. O(s) período(s) informado(s) deve(m) abranger todo
        o período previsto no registro 0000. Poderá coexistir um período mensal com períodos decendiais. Para os períodos
        decendiais, não poderá haver sobreposição ou omissão de datas.
        """
        _order = []

        def __init__(self):
            super(bloco_e.registro_E500, self).__init__()
            self.REG = 'E500'  # Texto fixo contendo
            self.nivel_h = 2  # nível
            self.pai = 'E001'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.IND_APUR = ''
            self.DT_INI = ''
            self.DT_FIN = ''
            self.fieldnames = ('REG', 'IND_APUR', 'DT_INI', 'DT_FIN')
            self.formato = self.get_formato()

    class registro_E510(TrackedAttributesClass):
        """
        REGISTRO E510: CONSOLIDAÇÃO DOS VALORES DO IPI.
        Este registro deve ser preenchido com os valores consolidados do IPI, de acordo com o período informado no
        registro E500, tomando-se por base as informações prestadas no registro C170.
        A consolidação se dará pela sumarização do valor contábil, base de cálculo e imposto relativo a todas as
        operações, conforme a combinação de CFOP e código da situação tributária do IPI (CST_IPI).
        As informações oriundas dos itens dos documentos fiscais – registro C170 ou do documento NF-e de emissão
        própria – serão consideradas no período de apuração mensal ou decendial, conforme preenchimento do campo IND_APUR
        """
        _order = []

        def __init__(self):
            super(bloco_e.registro_E510, self).__init__()
            self.REG = 'E510'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'E500'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.CFOP = ''
            self.CST_IPI = ''
            self.VL_CONT_IPI = ''
            self.VL_BC_IPI = ''
            self.VL_IPI = ''
            self.fieldnames = ('REG', 'CFOP', 'CST_IPI', 'VL_CONT_IPI', 'VL_BC_IPI', 'VL_IPI')
            self.formato = self.get_formato()

    class registro_E520(TrackedAttributesClass):
        """
        REGISTRO E520: APURAÇÃO DO IPI.
        Este registro deve ser preenchido para demonstração da apuração do IPI no período.
        """
        _order = []

        def __init__(self):
            super(bloco_e.registro_E520, self).__init__()
            self.REG = 'E520'  # Texto fixo contendo
            self.nivel_h = 3  # nível
            self.pai = 'E500'
            self.ocorrencia = '1'  # ocorrência por arquivo
            self.VL_SD_ANT_IPI = ''
            self.VL_DEB_IPI = ''
            self.VL_CRED_IPI = ''
            self.VL_OD_IPI = ''
            self.VL_OC_IPI = ''
            self.VL_SC_IPI = ''
            self.VL_SD_IPI = ''
            self.fieldnames = ('REG', 'VL_SD_ANT_IPI', 'VL_DEB_IPI', 'VL_CRED_IPI', 'VL_OD_IPI',
                               'VL_OC_IPI', 'VL_SC_IPI', 'VL_SD_IPI')
            self.formato = self.get_formato()

    class registro_E530(TrackedAttributesClass):
        """
        REGISTRO E530: AJUSTES DA APURAÇÃO DO IPI.
        Este registro deve ser apresentado para discriminar os ajustes lançados nos campos Outros Débitos e Outros
        Créditos do registro E520.
        """
        _order = []

        def __init__(self):
            super(bloco_e.registro_E530, self).__init__()
            self.REG = 'E530'  # Texto fixo contendo
            self.nivel_h = 4  # nível
            self.pai = 'E520'
            self.ocorrencia = 'N'  # ocorrência por arquivo
            self.IND_AJ = ''
            self.VL_AJ = ''
            self.COD_AJ = ''
            self.IND_DOC = ''
            self.NUM_DOC = ''
            self.DESCR_AJ = ''
            self.fieldnames = ()
            self.formato = self.get_formato()

    class registro_E990(TrackedAttributesClass):
        """
        REGISTRO E990: ENCERRAMENTO DO BLOCO E
        Este registro destina-se a identificar o encerramento do Bloco E e a informar a quantidade de linhas (registros)
        existentes no bloco.
        """
        _order = []

        def __init__(self):
            super(bloco_e.registro_E990, self).__init__()
            self.REG = 'E990'  # Texto fixo contendo
            self.nivel_h = 1  # nível
            self.pai = '0000'
            self.ocorrencia = '1'  #ocorrência por arquivo
            self.QTD_LIN_E = ''
            self.fieldnames = ('REG', 'QTD_LIN_E')
            self.formato = self.get_formato()
